#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: extract
#------------------------------------------------------------------------------
# Command to run the main extraction process
#==============================================================================

import argparse, os

import main


#==============================================================================
# Default values
#==============================================================================

DEFAULT_SOURCE_TYPE = 'amr' 
DEFAULT_SOURCE_CORPUS = "samples/s1/"
DEFAULT_TARGET_ID =  'DefaultTargetId'
DEFAULT_BASE_OUTPUT_DIR =  None
DEFAULT_ENGINE = 'tenet'

   
#==============================================================================
# Main Process
#==============================================================================

def control_arguments(): 
    arg_parser = argparse.ArgumentParser(
        description=("TENET - Tool for Extraction using Net Extension ",
                     "by (semantic) Transduction"))     
    arg_parser.add_argument("--source_type", nargs='?',
                            default=DEFAULT_SOURCE_TYPE,
                            help="source_type: amr or unl")   
    arg_parser.add_argument("--source_corpus",
                            default=DEFAULT_SOURCE_CORPUS,
                            help="source_corpus: source corpus directory with slash")  
    arg_parser.add_argument("--target_id",
                            default=DEFAULT_TARGET_ID,
                            help="target_id: id for the target ontology")    
    arg_parser.add_argument("--base_output_dir",
                            default=DEFAULT_BASE_OUTPUT_DIR,
                            help="base_output_dir base output directory with slash")    
    arg_parser.add_argument("--engine",
                            default=DEFAULT_ENGINE,
                            help="engine: shacl, tenet or new")  
    args = arg_parser.parse_args()
    return args
    

if __name__ == '__main__':
    
    args = control_arguments()
    onto_prefix=args.target_id
    out_dir_path = args.base_output_dir
    out_file_name = f'{onto_prefix}_factoid.ttl'
    out_file_path = f'{out_dir_path}{out_file_name}'
    technical_dir_path = f'{out_dir_path}technical-data/'
    
    if os.path.isfile(args.source_corpus):
        amrld_file_path = args.source_corpus
        main.create_ontology_from_amrld_file(amrld_file_path,
                                             base_ontology_path=None, 
                                             onto_prefix=onto_prefix, 
                                             out_file_path=out_file_path,
                                             technical_dir_path=technical_dir_path)
    
    if os.path.isdir(args.source_corpus):
        amrld_dir_path = args.source_corpus
        main.create_ontology_from_amrld_dir(amrld_dir_path,
                                            base_ontology_path=None, 
                                            onto_prefix=onto_prefix, 
                                            out_file_path=out_file_path,
                                            technical_dir_path=technical_dir_path)