#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Composite Property Net
#------------------------------------------------------------------------------
# Class to handle semantic nets 
#==============================================================================

from febTransduction.net import PropertyNet


#==============================================================================
# Net Class
#==============================================================================

class CompositePropertyNet(PropertyNet):
    """ Class to handle semantic net.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, support_graph, uri=None):

        # -- Parent init
        super().__init__(support_graph, uri)
        
        # -- Net Type
        self.type_name = 'compositeProperty'
        self.type_id = 'Composite_Property_Net'
        self.type_uri = f'net:{self.type_id}'
        
        # -- Net Attributes
        self._core_role = None
        self._target_argument_node = []
        self._property_type = None
        self._restriction = []

        
    #--------------------------------------------------------------------------
    # Accessors for Net Attributes
    #--------------------------------------------------------------------------
        
    @property
    def core_role(self):
        self._core_role = super().get_attribute_value(core_role=self._core_role)
        return self._core_role
    
    @core_role.setter
    def core_role(self, new_value):
        self._core_role = self.set_attribute_value(self._core_role, new_value)

        
    @property
    def target_argument_node(self):
        self._target_argument_node = super().get_attribute_value(target_argument_node=self._target_argument_node)
        return self._target_argument_node
    
    @target_argument_node.setter
    def target_argument_node(self, new_value):
        self._target_argument_node = self.set_attribute_value(self._target_argument_node, new_value)

        
    @property
    def property_type(self):
        self._property_type = super().get_attribute_value(property_type=self._property_type)
        return self._property_type
    
    @property_type.setter
    def property_type(self, new_value):
        self._property_type = self.set_attribute_value(self._property_type, new_value)

        
    @property
    def restriction(self):
        self._restriction = super().get_attribute_value(restriction=self._restriction)
        return self._restriction
    
    @restriction.setter
    def restriction(self, new_value):
        self._restriction = self.set_attribute_value(self._restriction, new_value)
