#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Pattern
#------------------------------------------------------------------------------
# Class to define a pattern to find in a semantic graph. The pattern is 
# composed of a list of semantic nets to be extracted from the graph and 
# associated with a set of clauses (identification or relational clauses).
#==============================================================================

import logging

from rdflib import Graph
from rdflib import Namespace
from rdflib.namespace import NamespaceManager

import febTransduction.query_builder as query_builder
import febTransduction.net as net

from febTransduction.semantic_net_rdf_reference import SemanticNetReferenceHandle


#==============================================================================
# Class
#==============================================================================

class Pattern:
    """ Class to define a pattern to find in a semantic graph. The pattern is 
        composed of a list of semantic nets to be extracted from the graph and 
        associated with a set of clauses (identification or relational clauses).
    """
        
    #--------------------------------------------------------------------------
    # Constructor
    #--------------------------------------------------------------------------
              
    def __init__(self, *nets):
        
        # -- Base
        self.label = f' ----- finding'
        self.net_list = []
        for net in nets:
            self.label += f' {net}'
            self.net_list.append(f'?{net}')      
            
        # -- Reference Handle
        self.referenceHandle = SemanticNetReferenceHandle() 
        
        # -- Pattern
        self._identification_pattern_list = []
        self._relation_pattern_list = []

    
    #--------------------------------------------------------------------------
    # Method(s) to add pattern
    #--------------------------------------------------------------------------
    
    def add_identification_pattern(self, net, **net_attribute):
        for attr_ref in net_attribute.keys():
            attr_predicate = self.referenceHandle.get_predicate(attr_ref)
            attr_value = net_attribute.get(attr_ref)
            self._identification_pattern_list.append(())

    def add_relation_pattern(self, net_1, relation, net_2):
        self._relation_pattern_list.append((net_1, relation, net_2))
        
    
    #--------------------------------------------------------------------------
    # Pattern Application Method
    #--------------------------------------------------------------------------
                
    def apply(self, graph):
        
        # -- Select Data List
        select_data_list = []
        for net in net_list:
            select_data_list.append(net.id)
        
        # -- Clause List
        clause_list = []
        for (attr_predicate, attr_value) in relation_pattern_list:
            clause_list.append(f'{self.id} {attr_predicate} {attr_value}.')
        for (net_1, relation, net_2) in relation_pattern_list:
            clause_list.append(f'{net_1.id} {relation} {net_2.id}.')
        
        # -- Query Generation
        query_code = query_builder.generate_select_query(select_data_list, clause_list)
        query_result = graph.query(test_query)  
        
        return query_result