#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Naming Computer
#------------------------------------------------------------------------------
# Class grouping methods to compute URI for semantic nets (and their 
# attributes)
#==============================================================================

from rdflib import Graph
from rdflib import Namespace
from rdflib.namespace import NamespaceManager


#==============================================================================
# Prefix Definition
#==============================================================================

COMMON_PREFIX_DICT = {
    'xsd': 'http://www.w3.org/2001/XMLSchema#',
    'owl': 'http://www.w3.org/2002/07/owl#',
    'rdf': 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
    'rdfs': 'http://www.w3.org/2000/01/rdf-schema#',
    }


TENET_PREFIX_DICT = {
    'net': 'https://tenet.tetras-libre.fr/semantic-net#',
    'cprm': 'https://tenet.tetras-libre.fr/config/parameters#',
    'fprm': 'https://tenet.tetras-libre.fr/frame/parameters#',
    'base-out': 'https://tenet.tetras-libre.fr/base-ontology#',
    'ext-out': 'https://tenet.tetras-libre.fr/extract-result#'
    }


AMR_STRUCTURE_PREFIX_DICT = {
    'ns1': 'http://amr.isi.edu/frames/ld/v1.2.2/',
    'ns2': 'http://amr.isi.edu/rdf/amr-terms#',
    'ns3': 'http://amr.isi.edu/rdf/core-amr#',
    'ns4': 'http://amr.isi.edu/entity-types#',
    'amr': 'https://amr.tetras-libre.fr/rdf/schema#'
    }


#==============================================================================
# Getter Method(s)
#==============================================================================

def get_prefix_dict():    
    prefix_dict = {}
    prefix_dict.update(COMMON_PREFIX_DICT)
    prefix_dict.update(TENET_PREFIX_DICT)
    prefix_dict.update(AMR_STRUCTURE_PREFIX_DICT)
    return prefix_dict
   
    
def get_prefix_list():    
    prefix_list = []
    prefix_list += COMMON_PREFIX_DICT.items()
    prefix_list += TENET_PREFIX_DICT.items()
    prefix_list += AMR_STRUCTURE_PREFIX_DICT.items()
    return prefix_list



#==============================================================================
# Namespace Update Method(s)
#==============================================================================

def update_graph_namespacemanager(graph):
    prefix_list = get_prefix_list()
    for prefix, uri in prefix_list:
        graph.bind(prefix, Namespace(uri))
    return graph