#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Naming Computer
#------------------------------------------------------------------------------
# Class grouping methods to compute URI for semantic nets (and their 
# attributes)
#==============================================================================

import rdflib
from rdflib import URIRef, Graph
from rdflib.term import _is_valid_uri



#==============================================================================
# Method to produce URIRef
#==============================================================================

def __create_uriref(uri):
    assert isinstance(uri, str), f'Houston, we have a problem: uri is not a string'
    
    if (uri.startswith("<") & uri.endswith(">")):
        uri = uri[1:-1]
    
    if not isinstance(uri, rdflib.term.URIRef):
        uri = rdflib.URIRef(uri)
    
    assert isinstance(uri, rdflib.term.URIRef), f'Houston, we have a problem: result uri is not an URIRef'
    
    return uri


def __update_uri_with_prefix(graph, uri):
    assert isinstance(uri, str), f'Houston, we have a problem: uri is not a string'
    
    if uri.startswith("http"):
        uri = rdflib.URIRef(uri.n3(graph.namespace_manager))
    
    assert _is_valid_uri(uri), f'Houston, we have a problem: unknown url in uri'
    
    return uri


def produce_uriref(graph, uri):
    """Create a URIRef with the same validation func used by URIRef

    Except here an InvalidURIRef exception is raised.

    The RDFLib _is_valid_uri only checks for invalid characters. You can also add your
    own validation checks.
    """
    
    uriref = None
    if uri is not None:
        uriref = __create_uriref(uri)
        uriref = __update_uri_with_prefix(graph, uriref)
        uriref = __create_uriref(uriref) 
        assert _is_valid_uri(uriref), f'Houston, we have a problem: URI is not a valid uri'
    
    return uriref



#==============================================================================
# Method to produce Litteral
#==============================================================================