#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Net Query Builder
#------------------------------------------------------------------------------
# Class to generate SPARQL query parts related to semantic nets 
#==============================================================================

# -- Useful Constant(s)
DEFAULT_ATTRIBUTE_VALUE = f'\"NA\"'
INDENT_STR = '            '
SENTENCE_REF = '?sentenceRef'


#==============================================================================
# Net Class
#==============================================================================

class SemanticNetReferenceHandle:
    """ Class to handle RDF references (attributes) to semantic nets.
    """
    
    #--------------------------------------------------------------------------
    # Constructor
    #--------------------------------------------------------------------------
              
    def __init__(self):
             
        self._main_predicate_table = { 
            # *** [attribute_name: (predicate_ref, variable_ref)] ***
            
            # Net
            'node':                     'coverNode',
            'base_node':                'coverBaseNode',
            'structure':                'hasStructure',
            'naming':                   'hasNaming',
            
            # Class Net
            'class_name':               'hasClassName',
            'mother_class_net':         'hasMotherClassNet',
            
            # Property Net
            'property_name':            'hasPropertyName',
            'core_role':                'isCoreRoleLinked',
            'target_argument_node':     'targetArgumentNode',
            'property_type':            'hasPropertyType',
            'property_name01':          'hasPropertyName01',
            'property_name10':          'hasPropertyName10',
            'property_name12':          'hasPropertyName12',
            
            # Individual Net
            'base_class_name':          'hasBaseClassName',
            'individual_label':         'hasIndividualLabel',
            
            # Value Net
            'value_label':              'hasValueLabel',
            
            # Phenomena Net
            'phenomena_type':           'hasPhenomenaType',
            'phenomena_ref':            'hasPhenomenaRef',
            
            # Composite Net Restriction
            'restriction':              'hasRestriction',
            'restriction01':            'hasRestriction01',
            
            # Restriction Net
            'target_node':              'coverTargetNode',
            'restriction_property':     'hasRestrictionOnProperty',
            'restriction_net_value':    'hasRestrictionNetValue'
            
            }
        
        
        self._track_predicate_table = { 
            # *** [attribute_name: predicate_ref] ***
            
            'progress_step':            'trackProgress',
            'main_net_composante':      'trackMainNetComposante',
            'net_composante':           'trackNetComposante'
            
            }

    
    #--------------------------------------------------------------------------
    # Accessor(s)
    #--------------------------------------------------------------------------
        
    def get_predicate_uri(self, attribute_name):
        
        assert (attribute_name in self._main_predicate_table.keys() or
                attribute_name in self._track_predicate_table.keys())
        
        predicate_uri = None
        
        if attribute_name in self._main_predicate_table.keys():
            predicate_rdf_reference = self._main_predicate_table[f'{attribute_name}']
            predicate_uri = f'net:{predicate_rdf_reference}'
            
        elif attribute_name in self._track_predicate_table.keys():
            predicate_rdf_reference = self._track_predicate_table[f'{attribute_name}']
            predicate_uri = f'net:{predicate_rdf_reference}'
            
        return predicate_uri
            
    
#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')
    
    print('\n -- Semantic Net Reference Table')
    net_reference_handle = SemanticNetReferenceHandle()
    
    print('\n -- Some test of getting predicate uri')
    
    def test_getter_1(attr_ref):
        attr_predicate = net_reference_handle.get_predicate_uri(attr_ref)
        print(f" >>> {attr_ref}: {attr_predicate}")
        
    test_getter_1('base_node')
    test_getter_1('progress_step')
    test_getter_1('no-name')
    test_getter_1('naming')
    
    print('\n' + ' *** - ***')