#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Class Net Query Builder
#------------------------------------------------------------------------------
# Class to generate SPARQL query parts related to semantic nets 
#==============================================================================

#==============================================================================
# Importing required modules
#==============================================================================

from .net import Net


#==============================================================================
# Net Class
#==============================================================================

class ClassNet(Net):
    """ Class to generate SPARQL query parts related to semantic nets.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, num='', signature=False):
        
        # -- Net Signature
        if not signature:
            self.type_name = 'class'
            self.type_id = 'Class_Net'
            self.id = f'?{self.type_name}Net{num}'
            self.type_uri = f'net:{self.type_id}'
        
        # -- Parent init
        super().__init__(signature=True)
        
        # -- Net Attributes
        self.class_name = f'{self.id}ClassName'
        
        self.predicate_table.update({
            'class_name': 'hasClassName'
            })


    
#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')    
        
    print('\n' + ' -- test: Net')
    net = AtomClassNet()
    print(net)
        
    print('\n' + ' -- test: update a test query')
    test_query= f"""[...]
        CONSTRUCT {{
            {net.construct(base_node='?node1',
                           class_name='system')}
        
        }}
        WHERE {{
            clause_1
            clause_2
            
            {net.complete_clauses_for_construction('?node1')}
            
            {net.bind_uri('{{node1.concept_label}}',
                          '{{node1.variable_label}}')}
        }}
    """
    print(test_query)
    
    print('\n' + ' *** - ***')