#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Composite Property Net Query Builder
#------------------------------------------------------------------------------
# Class to generate SPARQL query parts related to semantic nets 
#==============================================================================

#==============================================================================
# Importing required modules
#==============================================================================

from .property_net import PropertyNet


#==============================================================================
# Net Class
#==============================================================================

class CompositePropertyNet(PropertyNet):
    """ Class to generate SPARQL query parts related to semantic nets.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, num=''):
        
        # -- Net Signature
        self.type_name = 'compositeProperty'
        self.type_id = 'Composite_Property_Net'
        self.id = f'?{self.type_name}Net{num}'
        self.type_uri = f'net:{self.type_id}'
        
        # -- Parent init
        super().__init__(signature=True)
        
        # -- Net Attributes
        self.core_role = f'{self.id}CoreRole'
        self.target_argument_node = f'{self.id}TargetArgumentNode'
        self.property_type = f'{self.id}PropertyType'
        self.restriction = f'{self.id}Restriction'
        
        self.predicate_table.update({
            'core_role': 'isCoreRoleLinked',
            'target_argument_node': 'targetArgumentNode',
            'property_type': 'hasPropertyType',
            'restriction': 'hasRestriction'
            })


    
#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')    
        
    print('\n' + ' -- test: Net')
    net = AtomClassNet()
    print(net)
        
    print('\n' + ' -- test: update a test query')
    test_query= f"""[...]
        CONSTRUCT {{
            {net.construct(base_node='?node1',
                           class_name='system')}
        
        }}
        WHERE {{
            clause_1
            clause_2
            
            {net.complete_clauses_for_construction('?node1')}
            
            {net.bind_uri('{{node1.concept_label}}',
                          '{{node1.variable_label}}')}
        }}
    """
    print(test_query)
    
    print('\n' + ' *** - ***')