#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: SPARQL Query Builder
#------------------------------------------------------------------------------
# Class to define a Compositional Transduction Rule (CTR), namely a rule 
# associating a semantic graph pattern and a semantic net constructor.  
# Several methods are proposed to translate the rule into a sequence of SPARQL 
# queries applicable to a semantic graph.
#==============================================================================

# -- Useful Constant(s)
DEFAULT_ATTRIBUTE_VALUE = f'\"NA\"'
INDENT_STR = '            '
SENTENCE_REF = '?sentenceRef'


#==============================================================================
# Method to generate construct query
#==============================================================================

prefix_list = [('owl', '<http://www.w3.org/2002/07/owl#>'),
               ('rdf', '<http://www.w3.org/1999/02/22-rdf-syntax-ns#>'),
               ('rdfs', '<http://www.w3.org/2000/01/rdf-schema#>'),
               ('xsd', '<http://www.w3.org/2001/XMLSchema#>'),
               ('amr', '<https://amr.tetras-libre.fr/rdf/schema#>'),
               ('ns1', '<http://amr.isi.edu/frames/ld/v1.2.2/>'),
               ('ns2', '<http://amr.isi.edu/rdf/amr-terms#>'),
               ('ns3', '<http://amr.isi.edu/rdf/core-amr#>'),
               ('ns4', '<http://amr.isi.edu/entity-types#>'),
               ('net', '<https://tenet.tetras-libre.fr/semantic-net#>'),
               ('cprm', '<https://tenet.tetras-libre.fr/config/parameters#>'),
               ('fprm', '<https://tenet.tetras-libre.fr/frame/parameters#>'),
               ('base-out', '<https://tenet.tetras-libre.fr/base-ontology#>'),
               ('ext-out', '<https://tenet.tetras-libre.fr/extract-result#>')]


def get_prefix_def():
    prefix_def = ''
    for (ident, iri) in prefix_list:
        prefix_def += f'PREFIX {ident}: {iri}\n'
    return prefix_def


def generate_construct_query(construct_part, clause_part, binding_part=''):
    prefix = get_prefix_def()
    return f"""{prefix}
CONSTRUCT {{ {construct_part}
}}
WHERE {{ {clause_part}
{binding_part}
}}
"""           
            
    
#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')
    
    print('\n -- Generate SPARQL query')
    query = generate_construct_query('construct', 'identify', 'BIND')
    print(query)
        
    print('\n' + ' *** - ***')