#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Atom Property Net Query Builder
#------------------------------------------------------------------------------
# Class to generate SPARQL query parts related to semantic nets 
#==============================================================================

#==============================================================================
# Importing required modules
#==============================================================================

from .property_net import PropertyNet


#==============================================================================
# Net Class
#==============================================================================

class AtomPropertyNet(PropertyNet):
    """ Class to generate SPARQL query parts related to semantic nets.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, num=''):
        
        # -- Net Signature
        self.type_name = 'atomProperty'
        self.type_id = 'Atom_Property_Net'
        self.id = f'?{self.type_name}Net{num}'
        self.type_uri = f'net:{self.type_id}'
        
        # -- Parent init
        super().__init__(signature=True)
        
        # -- Net Attributes
        self.core_role = f'{self.id}CoreRole'
        self.target_argument_node = f'{self.id}TargetArgumentNode'
        self.property_type = f'{self.id}PropertyType'
        #self.property_name = f'{self.id}PropertyName'
        self.property_name01 = f'{self.id}PropertyName01'
        self.property_name10 = f'{self.id}PropertyName10'
        self.property_name12 = f'{self.id}PropertyName12'
        
        self.predicate_table.update({
            'core_role': 'isCoreRoleLinked',
            'target_argument_node': 'targetArgumentNode',
            'property_type': 'hasPropertyType',
            #'property_name': 'hasPropertyName',
            'property_name01': 'hasPropertyName01',
            'property_name10': 'hasPropertyName10',
            'property_name12': 'hasPropertyName12'
            })