#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Value Net Query Builder
#------------------------------------------------------------------------------
# Class to generate SPARQL query parts related to semantic nets 
#==============================================================================

#==============================================================================
# Importing required modules
#==============================================================================

from .net import Net


#==============================================================================
# Net Class
#==============================================================================

class ValueNet(Net):
    """ Class to generate SPARQL query parts related to semantic nets.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, num=''):
        
        # -- Net Signature
        self.type_name = 'value'
        self.type_id = 'Value_Net'
        self.id = f'?{self.type_name}Net{num}'
        self.type_uri = f'net:{self.type_id}'
        
        # -- Parent init
        super().__init__(signature=True)
        
        # -- Net Attributes
        self.value_label = f'{self.id}ValueLabel'
        
        self.predicate_table.update({
            'value_label': 'hasValueLabel'
            })


    
#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')    
        
    print('\n' + ' -- test: Net')
    net = ValueNet()
    print(net)
        
    print('\n' + ' -- test: update a test query')
    test_query= f"""[...]
        CONSTRUCT {{
            {net.construct(value_label='a-value')}
        
        }}
        WHERE {{
            clause_1
            clause_2
            
            {net.complete_clauses_for_construction('?node1')}
            
            {net.bind_uri('{{a_label}}')}
        }}
    """
    print(test_query)
    
    print('\n' + ' *** - ***')