#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis of 
# AMR structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule_set = {}

 
# ---------------------------------------------
# Net Expansion: Classification
# ---------------------------------------------

rule_set['classify-net-from-core-1'] = {
    'label': "classify-net-from-core-1",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " Core property :ARG0 "),
    'construction': """
        ?rightClassNet net:hasClassType base-out:Entity.
    """,
    'clause': """
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net].
        ?leftNet amr:role_ARG0 ?rightClassNet.
    """,
    'binding': """
    """
}

rule_set['classify-net-from-core-2'] = {
    'label': "classify-net-from-core-2",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " Core property :ARG1 "),
    'construction': """
        ?rightClassNet net:hasClassType base-out:Entity.
    """,
    'clause': """
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net].
        ?leftNet amr:role_ARG1 ?rightClassNet. 
    """,
    'binding': """
    """
}


rule_set['classify-net-from-core-3'] = {
    'label': "classify-net-from-core-3",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " Core property :ARG2 "),
    'construction': """
        # -- New class net
        ?newNet a net:Individual_Net ;
            net:fromClassNet ?rightClassNet ;
            net:hasStructure ?sentenceRef ;
            net:coverBaseNode ?baseLeaf ;
            net:hasBaseClassName 'Feature' ;
            net:hasIndividualLabel ?rightConceptName.
        ?restrictionNet net:hasRestrictionNetValue ?newNet.
        
        # -- Original net becomes deprecated 
        # -- old --- ?rightClassNet net:deprecated true.
              
        # -- Propagation of relations (from nodes to nets)
        ?inRelationRole a net:Relation.
        ?inNet ?inRelationRole ?newNet.
        ?outRelationRole a net:Relation.
        ?newNet ?outRelationRole ?outNet.
    """,
    'clause': """
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net] ;
            net:hasStructure ?sentenceRef ;
            net:coverBaseNode ?baseLeaf ;
            net:hasClassName ?rightConceptName.
        OPTIONAL { ?restrictionNet net:hasRestrictionNetValue ?rightClassNet. }
        ?leftNet amr:role_ARG2 ?rightClassNet. 
        
        # -- Identify inbound relations linked to the base leaf (for propagation) 
        	OPTIONAL {?inNet a [rdfs:subClassOf* net:Net] ;
                       net:coverBaseNode ?inLeaf.
                  ?inLeaf ?inRelationEdge ?baseLeaf.    
                  ?inRelationEdge amr:hasAmrRole ?inRelationRole.}
            
        # -- Identify outgoing relations linked to the base leaf (for propagation) 
        	OPTIONAL {?outNet a [rdfs:subClassOf* net:Net] ;
                       net:coverBaseNode ?outLeaf.
                  ?baseLeaf ?outRelationEdge ?outLeaf.    
                  ?outRelationEdge amr:hasAmrRole ?outRelationRole.}
    """,
    'binding': """    
        # -- New class net
        BIND (CONCAT(str(net:), 'individual') AS ?n1).
        BIND (CONCAT(?n1, '_', ?rightConceptName) AS ?n2).
        BIND (CONCAT(?n2, '_', 'fromClass') AS ?n3).
        BIND (uri(?n3) AS ?newNet).
    """
}

# rule_set['classify-net-from-mod'] = {
#     'label': "classify-net-from-mod",
#     'comment': ("Classify Class Net from relations corresponding to: ",
#                 " Non-Core property :MOD "),
#     'construction': """
#         # -- Entity net
#         ?leftClassNet net:hasClassType base-out:Entity.
            
#         # -- New class net
#         ?newNet a net:Individual_Net ;
#             net:fromClassNet ?rightClassNet ;
#             net:hasStructure ?sentenceRef ;
#             net:coverBaseNode ?baseLeaf ;
#             net:hasBaseClassName 'Feature' ;
#             net:hasIndividualLabel ?newClassName.
#         ?restrictionNet net:hasRestrictionNetValue ?newNet.
        
#         # -- Original net becomes deprecated 
#         # -- old --- ?rightClassNet net:deprecated true.
              
#         # -- Propagation of relations (from nodes to nets)
#         ?inRelationRole a net:Relation.
#         ?inNet ?inRelationRole ?newNet.
#         ?outRelationRole a net:Relation.
#         ?newNet ?outRelationRole ?outNet.
#     """,
#     'clause': """
#         ?leftClassNet a [rdfs:subClassOf* net:Class_Net];
#             net:hasClassName ?leftConceptName.
#         ?rightClassNet a [rdfs:subClassOf* net:Class_Net] ;
#             net:hasStructure ?sentenceRef ;
#             net:coverBaseNode ?baseLeaf ;
#             net:hasClassName ?rightConceptName.
#         OPTIONAL { ?restrictionNet net:hasRestrictionNetValue ?rightClassNet. }
#         ?leftClassNet amr:role_mod ?rightClassNet.
        
#         # -- Identify inbound relations linked to the base leaf (for propagation) 
#          	OPTIONAL {?inNet a [rdfs:subClassOf* net:Net] ;
#                         net:coverBaseNode ?inLeaf.
#                   ?inLeaf ?inRelationEdge ?baseLeaf.    
#                   ?inRelationEdge amr:hasAmrRole ?inRelationRole.}
            
#         # -- Identify outgoing relations linked to the base leaf (for propagation) 
#          	OPTIONAL {?outNet a [rdfs:subClassOf* net:Net] ;
#                         net:coverBaseNode ?outLeaf.
#                   ?baseLeaf ?outRelationEdge ?outLeaf.    
#                   ?outRelationEdge amr:hasAmrRole ?outRelationRole.}
#     """,
#     'binding': """
# 		# -- New class Name
# 		BIND (CONCAT(?rightConceptName, '-', ?leftConceptName) AS ?newClassName).
        
#         # -- New class net URI
#         BIND (CONCAT(str(net:), 'individual') AS ?n1).
#         BIND (CONCAT(?n1, '_', ?newClassName) AS ?n2).
#         BIND (CONCAT(?n2, '_', 'fromClass') AS ?n3).
#         BIND (uri(?n3) AS ?newNet).
#     """
# }

rule_set['classify-net-from-part'] = {
    'label': "classify-net-from-part",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " Non-Core property :PART "),
    'construction': """
        ?leftClassNet net:hasClassType base-out:Entity.
        ?rightClassNet net:hasClassType base-out:Entity.
    """,
    'clause': """
        ?leftClassNet a [rdfs:subClassOf* net:Class_Net].
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net].
        ?leftClassNet amr:role_part ?rightClassNet.
    """,
    'binding': """
    """
}

rule_set['classify-net-from-domain'] = {
    'label': "classify-net-from-domain",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " Non-Core property :DOMAIN "),
    'construction': """
        ?leftClassNet net:hasMotherClassNet ?rightClassNet.
    """,
    'clause': """
        ?leftClassNet a [rdfs:subClassOf* net:Class_Net].
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net].
        ?leftClassNet amr:role_domain ?rightClassNet.
    """,
    'binding': """
    """
}

rule_set['classify-net-from-degree-phenomena-1'] = {
    'label': "classify-net-from-degree-phenomena-1",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " (1) phenomena :DEGREE ",
                " (2) core role :ARG1 or :ARG5"),
    'construction': """
        ?rightClassNet net:hasClassType base-out:Entity.
    """,
    'clause': """
        ?phenomenaNet a net:Phenomena_Net ;
            net:targetArgumentNode ?rightLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net].
        ?phenomenaNet ?role ?rightClassNet.
        FILTER (?role = amr:role_ARG1 ||
                ?role = amr:role_ARG5).   
    """,
    'binding': """
    """
}

rule_set['classify-net-from-degree-phenomena-2'] = {
    'label': "classify-net-from-degree-phenomena-2",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " (1) phenomena :DEGREE ",
                " (2) core role :ARG2"),
    'construction': """
        ?newNet a net:Individual_Net ;
            net:fromClassNet ?rightClassNet ;
            net:hasStructure ?sentenceRef ;
            net:coverBaseNode ?baseLeaf ;
            net:hasBaseClassName 'Feature' ;
            net:hasIndividualLabel ?rightConceptName.
        ?restrictionNet net:hasRestrictionNetValue ?newNet.
        
        # -- Original net becomes deprecated 
        # -- old --- ?rightClassNet net:deprecated true.
              
        # -- Propagation of relations (from nodes to nets)
        ?inRelationRole a net:Relation.
        ?inNet ?inRelationRole ?newNet.
        ?outRelationRole a net:Relation.
        ?newNet ?outRelationRole ?outNet.
    """,
    'clause': """
        ?phenomenaNet a net:Phenomena_Net ;
            net:targetArgumentNode ?baseLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net] ;
            net:hasStructure ?sentenceRef ;
            net:hasClassName ?rightConceptName.
        OPTIONAL { ?restrictionNet net:hasRestrictionNetValue ?rightClassNet. }
        ?phenomenaNet amr:role_ARG2 ?rightClassNet.
        
        # -- Identify inbound relations linked to the base leaf (for propagation) 
         	OPTIONAL {?inNet a [rdfs:subClassOf* net:Net] ;
                        net:coverBaseNode ?inLeaf.
                  ?inLeaf ?inRelationEdge ?baseLeaf.    
                  ?inRelationEdge amr:hasAmrRole ?inRelationRole.}
            
        # -- Identify outgoing relations linked to the base leaf (for propagation) 
         	OPTIONAL {?outNet a [rdfs:subClassOf* net:Net] ;
                        net:coverBaseNode ?outLeaf.
                  ?baseLeaf ?outRelationEdge ?outLeaf.    
                  ?outRelationEdge amr:hasAmrRole ?outRelationRole.}
    """,
    'binding': """
        BIND (CONCAT(str(net:), 'individual') AS ?n1).
        BIND (CONCAT(?n1, '_', ?rightConceptName) AS ?n2).
        BIND (CONCAT(?n2, '_', 'fromClass') AS ?n3).
        BIND (uri(?n3) AS ?newNet).
    """
}

rule_set['classify-net-from-degree-phenomena-3'] = {
    'label': "classify-net-from-degree-phenomena-3",
    'comment': ("Classify Class Net from relations corresponding to: ",
                " (1) phenomena :DEGREE ",
                " (2) core role :ARG3"),
    'construction': """
        ?rightClassNet net:hasClassType base-out:Degree.
    """,
    'clause': """
        ?phenomenaNet a net:Phenomena_Net ;
            net:targetArgumentNode ?rightLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?rightClassNet a [rdfs:subClassOf* net:Class_Net].
        ?phenomenaNet amr:role_ARG3 ?rightClassNet. 
    """,
    'binding': """
    """
}

rule_set['propagate-individual-1'] = {
    'label': "propagate-individual-1",
    'comment': ("Propagate Individual by completing Individual Net for: ",
                " (1) same base node cover between several classes"),
    'construction': """
        ?individualNet net:hasMotherClassNet ?classNet.
    """,
    'clause': """
        ?individualNet a net:Individual_Net ;
            net:coverBaseNode ?sameBaseLeaf.
        ?classNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?sameBaseLeaf.   
    """,
    'binding': """
    """
}

rule_set['propagate-individual-2'] = {
    'label': "propagate-individual-2",
    'comment': ("Propagate Individual by completing Individual Net for: ",
                " (1) link between conjunction and domain phenomenas"),
    'construction': """
        ?individualNet net:hasMotherClassNet ?classNet.
    """,
    'clause': """
        ?classNet a [rdfs:subClassOf* net:Class_Net].  
        ?individualNet a net:Individual_Net.  
        ?classNet amr:role_domain ?individualNet. 
    """,
    'binding': """
    """
}

rule_set['reclassify-deprecated-net'] = {
    'label': "reclassify-deprecated-net",
    'comment': ("Reclassify deprecated net as Deprecated_Net instances"),
    'construction': """
        # -- Net becomes deprecated net 
        ?net a net:Deprecated_Net.
    """,
    'clause': """
        # -- Identify net with deprecated mark
		?net a [rdfs:subClassOf* net:Net_Structure] ;
            net:deprecated true.
    """,
    'binding': """
    """
}

#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')    
        
    print('\n' + ' -- Test Query')
    rule = rule_set['propagate-individual-1']
    test_query_1 = f"""[...]
        CONSTRUCT {{
            {rule['construction']}
            
        }}
        WHERE {{
            {rule['clause']}
            
            {rule['binding']}
            
        }}
    """
    print(test_query_1)    
    
    print('\n' + ' *** - ***')