#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis 
# of AMR structures, at 'Net Expansion' level
#==============================================================================

if __name__ == '__main__':
    import os, sys
    LIB_PATH = f'{os.path.dirname(os.path.abspath(__file__))}/../../..'
    sys.path.insert(0, os.path.abspath(LIB_PATH))
    print(sys.path[0])

import janTransduction as transduction
import janTransduction.net as net


#==============================================================================
# Rule to analyze conjunction phenomena 
#==============================================================================

# -- Net Instanciations
property_net = net.PropertyNet()
class_net_0 = net.ClassNet(0)
class_net_1 = net.ClassNet(1)
phenomena_net = net.PhenomenaNet()
or_composite_class_net = net.OrCompositeClassNet()

def jan_analyze_phenomena_or_1():

    # -- Net Instanciation
    property_net = net.PropertyNet()
    class_net_0 = net.ClassNet(0)
    phenomena_net = net.PhenomenaNet()
    or_composite_class_net = net.OrCompositeClassNet()

    # -- Rule Initialization    
    rule = transduction.Rule('"or" phenomena analysis 1 (targetting class)', 
                             or_composite_class_net)
    
    # -- Net Composition
    rule.add_identification_pattern(phenomena_net, phenomena_type='amr:phenomena_conjunction_or')
    rule.add_composition_pattern(property_net, 'amr:role_ARG0', class_net_0)
    rule.add_composition_pattern(property_net, 'amr:role_ARG1', phenomena_net)
    rule.compose(class_net_0, property_net, phenomena_net)
    
    # -- Data Computation
    # TODO
    
    # -- Restriction Computation
    # TODO
    
    # -- Relation Propagation
    # TODO
    
    # -- Finalization
    # TODO
    
    return rule


def jan_analyze_phenomena_or_2():

    # -- Net Instanciation
    property_net_0 = net.PropertyNet(0)
    property_net_1 = net.PropertyNet(1)
    phenomena_net = net.PhenomenaNet()
    or_composite_class_net = net.OrCompositeClassNet()

    # -- Rule Initialization    
    rule = transduction.Rule('"or" phenomena analysis 2 (targetting property)', 
                             or_composite_class_net)
    
    # -- Net Composition
    rule.add_identification_pattern(phenomena_net, phenomena_type='amr:phenomena_conjunction_or')
    rule.add_composition_pattern(property_net_1, 'amr:role_ARG0', property_net_0)
    rule.add_composition_pattern(property_net_1, 'amr:role_ARG1', phenomena_net)
    rule.compose(property_net_0, property_net_1, phenomena_net)
    
    # -- Data Computation
    # rule.compute_data(mother_class_net=property_net_0.id)
    
    # -- Restriction Computation
    # TODO
    
    # -- Relation Propagation
    # TODO
    
    # -- Finalization
    # TODO
    
    return rule

            
            
    
#==============================================================================
# Development Test
#==============================================================================
    
if __name__ == '__main__':
    
    print('\n' + ' *** Development Test ***')  
        
    print('\n -- Rule')
    rule = analyze_phenomena_or_1()
    
    num = 0
    for query_label, query in rule.query_list:
        num += 1
        print(f'*** query {num} - {query_label} ***\n{query}\n')
    