#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis of 
# AMR structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# Query Builder Imports
#==============================================================================

#import query_builder.construct as construct
from query_builder.builders import *
from query_builder.element.net import Net


#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule_set = {}
 
# ---------------------------------------------
# Net Expansion: Conjunction Phenomena Net
# ---------------------------------------------

rule_set['and-conjunction-phenomena-application-1'] = {
    'label': "and-conjunction-phenomena-application-1",
    'comment': ("Apply conjunction phenomena, step 1: ",
                " (1) create logical set",
                " (2) FROM and-conjunction linking some nets and a property"),
    'construction': f"""
        {logical_set_net.construct(base_node=phenomena_net.base_node, 
                                   logical_constraint='"AND"',
                                   property_net=atom_property_net.id,
                                   content_net_1='?contentNet1')}
        {logical_set_net.add_attribute(content_net_2='?contentNet2')}
        {logical_set_net.add_attribute(content_net='?contentNet1')}
        {logical_set_net.add_attribute(content_net='?contentNet2')}
        {logical_set_net.add_attribute(content_net='?contentNet3')}
        {logical_set_net.add_attribute(content_net='?contentNet4')}
        {logical_set_net.add_attribute(content_net='?contentNet5')}
        {logical_set_net.add_attribute(content_net='?contentNet6')}
        {logical_set_net.add_attribute(content_net='?contentNet7')}
        {logical_set_net.add_attribute(content_net='?contentNet8')}
        {logical_set_net.add_attribute(content_net='?contentNet9')}

        {logical_set_net.propagate_relations()}
    """,
    'clause': f"""
        
        # *** Identify Property(-, arg1:PhenomenaNet) ***
        
        {atom_property_net.identify_net(core_role='true')}
        {atom_property_net.id} amr:role_ARG1 {phenomena_net.id}.
        
        
        # *** Identify Phenomena(AND-conjunction, contentNet*) ***
           
        {phenomena_net.identify_net(phenomena_type='amr:phenomena_conjunction_and')}
        
        # -- old --- ?relationOp rdfs:subClassOf* amr:AMR_Op_Role.
        {phenomena_net.identify_operator('1', '?contentNet')} 
        {phenomena_net.identify_optional_operator('2', '?contentNet')} 
        {phenomena_net.identify_optional_operator('3', '?contentNet')} 
        {phenomena_net.identify_optional_operator('4', '?contentNet')} 
        {phenomena_net.identify_optional_operator('5', '?contentNet')} 
        {phenomena_net.identify_optional_operator('6', '?contentNet')} 
        {phenomena_net.identify_optional_operator('7', '?contentNet')} 
        {phenomena_net.identify_optional_operator('8', '?contentNet')} 
        {phenomena_net.identify_optional_operator('9', '?contentNet')} 
        
    
        # *** Identify variable label of base leaf ***
        {phenomena_net.base_node} a amr:AMR_Leaf ;
            amr:hasVariable ?variable.
        ?variable amr:label ?varLabel.
        
        {logical_set_net.complete_clauses_for_construction(phenomena_net.base_node)}
    """,
    'binding': f"""        
        {logical_set_net.bind_uri(phenomena_net.phenomena_ref, '?varLabel')}
    """
}

rule_set['and-conjunction-phenomena-application-2'] = {
    'label': "and-conjunction-phenomena-application-2",
    'comment': ("Apply conjunction phenomena (step 2): ",
                " (1) complete Logical Set Net for naming"),
    'construction': f"""
        {logical_set_net.define_naming()}
    """,
    'clause': f"""
        
        # *** Identify LogicalSet Net ***  
        {logical_set_net.identify_net_without_optional_attribute(
            property_net=property_net.id,
            content_net_1=class_net_1.id,
            content_net_2=class_net_2.id)}
        
        
        # *** Identify property and classes ***
        {property_net.identify_net(core_role='true')}
        {class_net_1.identify_net()}
        {class_net_2.identify_net()}
        
    """,
    'binding': f"""
        {logical_set_net.bind_naming(property_net.property_name,
                                     class_net_1.class_name,
                                     class_net_2.class_name)}
    """
}

rule_set['and-conjunction-phenomena-application-3'] = {
    'label': "and-conjunction-phenomena-application-3",
    'comment': ("Apply conjunction phenomena (step 3): ",
                " (1) complete Logical Set Net with restriction(s)"),
    'construction': f"""
    
        {restriction_net.construct(restriction_property=property_net.id,
                                   restriction_net_value=class_net.id)}
        {restriction_net.add_attribute(node=property_net.node)} 
        {restriction_net.add_attribute(node=logical_set_net.node)} 
        {restriction_net.add_attribute(node=class_net.node)} 
        
        {logical_set_net.add_attribute(restriction=restriction_net.id)}
    """,
    'clause': f"""
        # *** Identify LogicalSet Net ***
        {logical_set_net.identify_net(property_net=property_net.id)}
        {logical_set_net.identify_content_net(class_net.id)}
        
        # *** Identify property and classes ***
        {property_net.identify_net(core_role='true')}
        {class_net.identify_net()}
    """,
    'binding': f"""        
        {restriction_net.bind_uri(property_net.property_name, class_net.class_name)}
    """
}

rule_set['and-conjunction-phenomena-application-4'] = {
    'label': "and-conjunction-phenomena-application-4",
    'comment': ("Apply conjunction phenomena (step 4): ",
                " (1) create composite class net",
                " (2) FROM property linking class and logical set"),
    'construction': f"""        
        {composite_class_net.construct(base_node=class_net_0.base_node,
                                       naming='?newClassName',
                                       class_name='?newClassName',
                                       mother_class_net=class_net_0.id)}
        {composite_class_net.compose(class_net_0, property_net, logical_set_net)}
    """,
    'clause': f"""
        # *** Identify Property(arg0:Class, arg1:LogicalSet) ***  
        {property_net.identify_net(core_role='true')}     
        {property_net.id} amr:role_ARG0 {class_net_0.id}.
        {property_net.id} amr:role_ARG1 {logical_set_net.id}.  
        
        # *** Identify class and logical set ***
        {class_net_0.identify_net()}
        {logical_set_net.identify_net(logical_constraint='"AND"')}        
        
        # *** condition: disjoint cover ***
        FILTER NOT EXISTS {{
            {class_net_0.id} net:coverNode ?node.
            {logical_set_net.id} net:coverNode ?node.
            }}      
        
        # *** Identify variable label of base leaf ***
        {class_net_0.base_node} a amr:AMR_Leaf ;
            amr:hasVariable ?variable.
        ?variable amr:label ?varLabel.
    """,
    'binding': f"""
		# -- New Class Name
		BIND (CONCAT({class_net_0.class_name}, '-', {logical_set_net.naming}) AS ?newClassName).
        
        {composite_class_net.bind_uri('?newClassName', '?varLabel')}
    """
}

rule_set['and-conjunction-phenomena-application-5'] = {
    'label': "and-conjunction-phenomena-application-5",
    'comment': ("Apply conjunction phenomena (step 5): ",
                " (1) complete Logical Set Net for relation propagation"),
    'construction': f"""
        {composite_class_net.define_structure()}     
        {composite_class_net.propagate_relations()}
    """,
    'clause': f"""
        # *** Identify CompositeClass with a LogicalSet composante ***
        {composite_class_net.identify_net()}
        {composite_class_net.filter_already_processed_net(Net.RELATION_PROPAGATED)}
        
        # *** Complete clauses for net construction ***
        {composite_class_net.complete_clauses_for_construction()}
    """,
    'binding': f"""
    """
}

rule_set['and-conjunction-phenomena-application-6'] = {
    'label': "and-conjunction-phenomena-application-6",
    'comment': ("Apply conjunction phenomena (step 6): ",
                " (1) complete Logical Set Net by adding restrictions"),
    'construction': f"""   
        {composite_class_net.add_attribute(restriction01=restriction_net.id)}
    """,
    'clause': f"""
        # *** Identify CompositeClass in progress step INIT ***
        {composite_class_net.identify_net()}
        {composite_class_net.filter_already_processed_net(Net.RESTRICTION_ADDED)}
        {logical_set_net.identify_net()}
        {composite_class_net.identify_composante(logical_set_net.id)}
        
        # *** Identify Restriction ***
        {restriction_net.identify_net()}
        {logical_set_net.identify_restriction(restriction_net.id)}
    """,
    'binding': f"""
    """
}

 
# ---------------------------------------------
# *** Under Development *** New Rule
# ---------------------------------------------

# -- Useful query builder(s)
# * TODO * property_net = PropertyNet()
# * TODO * class_net_0 = ClassNet(0)
# * TODO * phenomena_net = PhenomenaNet()
# * TODO * and_composite_class_net = AndCompositeClassNet()

def analyze_phenomena_and():
    rule = 'NewRule()' # !!! TODO !!!
    
    # rule.clause(f'{property_net.identify_net(core_role="true")}')
    # rule.clause(f'{property_net.id} amr:role_ARG0 {class_net_0.id}.')
    # rule.clause(f'{property_net.id} amr:role_ARG1 {phenomena_net.id}.')
    # rule.clause(f'{phenomena_net.identify_net(phenomena_type='amr:phenomena_conjunction_and')}')
    
    # rule.operate(f'{and_composite_class_net.construct(*TODO*)}')
    
    # * TODO * add restrictions for and_composite_class_net --op--> class_net
    
    # * TODO * rule.operate(and_composite_class_net.complete_clauses_for_construction())
    
    return rule
