#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis of 
# AMR structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# Query Builder Imports
#==============================================================================

#import query_builder.construct as construct
from query_builder.builders import *
from query_builder.element.net import Net


#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule_set = {}

 
# ---------------------------------------------
# Net Expansion: Polarity Phenomena Application
# ---------------------------------------------

rule_set['polarity-phenomena-application'] = {
    'label': "polarity-phenomena-application",
    'comment': ("Apply polarity phenomena to: ", 
                " (1) polarity relation on a property class. "),
    'construction': f"""
    
        # !!! TODO: restriction for negative polarity !!!
        
        {composite_property_net.construct(base_node=atom_property_net.base_node,
                                          naming='?newPropertyName',
                                          property_name='?newPropertyName')}

        {composite_property_net.propagate_relations()}
        
        {atom_property_net.deprecate()}
        
    """,
    'clause': f"""
        # *** Identify Polarity(p0:Property, 'negative') ***
        
        {atom_property_net.identify_net(core_role='true')}
        
        {atom_property_net.identify_relation('amr:role_polarity', value_net.id)}        
        {value_net.identify_net(value_label="'negative'")}
        
        # *** Identify variable label of base leaf ***
        {atom_property_net.base_node} a amr:AMR_Leaf ;
            amr:hasVariable ?variable.
        ?variable amr:label ?varLabel.
        
        {composite_property_net.complete_clauses_for_construction(atom_property_net.base_node)}
    """,
    'binding': f"""
		# -- New Property Name
		BIND (CONCAT('not', '-', {atom_property_net.property_name}) AS ?newPropertyName).
        
        {composite_property_net.bind_uri('?newPropertyName', '?varLabel')}
    """
}
