#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis of 
# AMR structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule_set = {}


# ---------------------------------------------
# Net Expansion: Conjunction Phenomena Net
# ---------------------------------------------

rule_set['expand-and-or-conjunction-phenomena-net'] = {
    'label': "expand-and-conjunction-phenomena-net",
    'comment': ("Propagate relations for AND/OR conjunction net with: ",
                " (1) incoming relation",
                " (2) outgoing :op relation"),
    'construction': """
        ?leftNet ?incomingRelation ?rightNet.
    """,
    'clause': """
        ?phenomenaNet a net:Phenomena_Net ;
            net:hasPhenomenaType ?phenomenaType.
        FILTER (?phenomenaType = amr:phenomena_conjunction_and || 
                ?phenomenaType = amr:phenomena_conjunction_or).
        ?leftNet ?incomingRelation ?phenomenaNet.
        ?phenomenaNet ?relationOp ?rightNet.  
        ?relationOp rdfs:subClassOf* amr:AMR_Op_Role.
    """,
    'binding': """
    """
}


# ---------------------------------------------
# Net Expansion: Degree Phenomena Net
# ---------------------------------------------

rule_set['expand-degree-phenomena-net-1'] = {
    'label': "expand-degree-phenomena-net-1",
    'comment': ("Expand Degree Phenomena Net with: ",
                " domain corresponding to :ARG1"),
    'construction': """
        ?degreePhenomenaNet net:targetDomain ?argTargetClassNet.
    """,
    'clause': """
        ?degreePhenomenaNet a net:Phenomena_Net ;
            net:coverBaseNode ?phenomenaLeaf ;
            net:targetArgumentNode ?argTargetLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?argTargetClassNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?argTargetLeaf.
        ?phenomenaLeaf ?argEdge ?argTargetLeaf.
        ?argEdge amr:hasAmrRole amr:role_ARG1.
    """,
    'binding': """
    """
}

rule_set['expand-degree-phenomena-net-2'] = {
    'label': "expand-degree-phenomena-net-2",
    'comment': ("Expand Degree Phenomena Net with: ",
                " attribute corresponding to :ARG2"),
    'construction': """
        ?degreePhenomenaNet net:targetAttribute ?argTargetClassNet.
    """,
    'clause': """
        ?degreePhenomenaNet a net:Phenomena_Net ;
            net:coverBaseNode ?phenomenaLeaf ;
            net:targetArgumentNode ?argTargetLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?argTargetClassNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?argTargetLeaf.
        ?phenomenaLeaf ?argEdge ?argTargetLeaf.
        ?argEdge amr:hasAmrRole amr:role_ARG2.
    """,
    'binding': """
    """
}

rule_set['expand-degree-phenomena-net-3'] = {
    'label': "expand-degree-phenomena-net-3",
    'comment': ("Expand Degree Phenomena Net with: ",
                " degree corresponding to :ARG3"),
    'construction': """
        ?degreePhenomenaNet net:targetDegree ?argTargetClassNet.
    """,
    'clause': """
        ?degreePhenomenaNet a net:Phenomena_Net ;
            net:coverBaseNode ?phenomenaLeaf ;
            net:targetArgumentNode ?argTargetLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?argTargetClassNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?argTargetLeaf.
        ?phenomenaLeaf ?argEdge ?argTargetLeaf.
        ?argEdge amr:hasAmrRole amr:role_ARG3.
    """,
    'binding': """
    """
}

rule_set['expand-degree-phenomena-net-4'] = {
    'label': "expand-degree-phenomena-net-4",
    'comment': ("Expand Degree Phenomena Net with: ",
                " range corresponding to :ARG4"),
    'construction': """
        ?degreePhenomenaNet net:targetRange ?argTargetClassNet.
    """,
    'clause': """
        ?degreePhenomenaNet a net:Phenomena_Net ;
            net:coverBaseNode ?phenomenaLeaf ;
            net:targetArgumentNode ?argTargetLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?argTargetClassNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?argTargetLeaf.
        ?phenomenaLeaf ?argEdge ?argTargetLeaf.
        ?argEdge amr:hasAmrRole amr:role_ARG4.
    """,
    'binding': """
    """
}

rule_set['expand-degree-phenomena-net-5'] = {
    'label': "expand-degree-phenomena-net-5",
    'comment': ("Expand Degree Phenomena Net with: ",
                " superlative corresponding to :ARG5"),
    'construction': """
        ?degreePhenomenaNet net:targetSuperlative ?argTargetClassNet.
    """,
    'clause': """
        ?degreePhenomenaNet a net:Phenomena_Net ;
            net:coverBaseNode ?phenomenaLeaf ;
            net:targetArgumentNode ?argTargetLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?argTargetClassNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?argTargetLeaf.
        ?phenomenaLeaf ?argEdge ?argTargetLeaf.
        ?argEdge amr:hasAmrRole amr:role_ARG5.
    """,
    'binding': """
    """
}

rule_set['expand-degree-phenomena-net-6'] = {
    'label': "expand-degree-phenomena-net-6",
    'comment': ("Expand Degree Phenomena Net with: ",
                " consequence corresponding to :ARG6"),
    'construction': """
        ?degreePhenomenaNet net:targetConsequence ?argTargetClassNet.
    """,
    'clause': """
        ?degreePhenomenaNet a net:Phenomena_Net ;
            net:coverBaseNode ?phenomenaLeaf ;
            net:targetArgumentNode ?argTargetLeaf ;
            net:hasPhenomenaType amr:phenomena_degree.
        ?argTargetClassNet a [rdfs:subClassOf* net:Class_Net] ;
        		net:coverBaseNode ?argTargetLeaf.
        ?phenomenaLeaf ?argEdge ?argTargetLeaf.
        ?argEdge amr:hasAmrRole amr:role_ARG6.
    """,
    'binding': """
    """
}