#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis of 
# AMR structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule_set = {}

 
# ---------------------------------------------
# Useful technical CTR
# ---------------------------------------------

rule_set['refine-cover-node-1'] = {
    'label': "refine-cover-node-1",
    'comment': ("Refine semantic net coverage indicators by: ",
                " calculating the set of all covered nodes"),
    'construction': """
        ?net net:coverNode ?baseLeaf.
        ?net net:coverNode ?argLeaf.
        ?net net:coverNode ?targetLeaf.
    """,
    'clause': """
        ?net a [rdfs:subClassOf* net:Net] ;
            net:coverBaseNode ?baseLeaf.
        OPTIONAL { ?net net:coverArgNode ?argLeaf. }
        OPTIONAL { ?net net:coverTargetNode ?targetLeaf. }
    """,
    'binding': """
    """
}

rule_set['refine-cover-node-2'] = {
    'label': "refine-cover-node-2",
    'comment': ("Refine semantic net coverage indicators by: ",
                " calculating the number of covered nodes"),
    'construction': """
        ?net net:coverNodeCount ?c.
    """,
    'clause': """
		SELECT ?net (COUNT(?leaf) AS ?c)
    		WHERE {
                ?net a [rdfs:subClassOf* net:Class_Net] ;
                		net:coverNode ?leaf.
        }
		GROUP BY ?net
    """,
    'binding': """
    """
}

# -- old ---
# rule_set['propagation-relations-to-nets'] = {
#     'label': "propagation-relations-to-nets",
#     'comment': ("Propagation relations between nodes",
#                 " to relations between nets"),
#     'construction': """
#         ?relationRole a net:Relation.
#         ?net1 ?relationRole ?net2.
#     """,
#     'clause': """
# 		?net1 a [rdfs:subClassOf* net:Net] ;
#             net:coverBaseNode ?leaf1.
#         	?net2 a [rdfs:subClassOf* net:Net] ;
#             net:coverBaseNode ?leaf2.
#         ?leaf1 ?relationEdge ?leaf2.    
#         ?relationEdge amr:hasAmrRole ?relationRole.
#     """,
#     'binding': """
#     """
# }
# -- ---