#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Old UNL CTR
#------------------------------------------------------------------------------
# Module grouping old sparql queries for the analysis of  UNL structures
#==============================================================================

#==============================================================================
# Prefix using in CTR
#==============================================================================

prefix = """
PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>
PREFIX cts: <https://tenet.tetras-libre.fr/transduction-schemes#>
PREFIX sh: <http://www.w3.org/ns/shacl#>
    
"""


#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule = {}

# ---------------------------------------------
# Old Preprocessing: Rule Update
# ---------------------------------------------

rule['upadte_preprocessing_rules'] = {
    'label': "NO-LABEL",
    'order': 0.101,
    'query': """
    CONSTRUCT {
       cts:preprocessing sh:rule ?rule.
    }
    WHERE {
       ?rule rdf:type sh:SPARQLRule.
       ?rule sh:order ?order.
       FILTER ( strStarts(str(?order),\"1.\")  ).
    }
    """
}

rule['update_net_extension_rules'] = {
    'label': "NO-LABEL",
    'order': 0.102,
    'query': """
    CONSTRUCT {
       cts:net_extension sh:rule ?rule.
    }
    WHERE {
       ?rule rdf:type sh:SPARQLRule.
       ?rule sh:order ?order.
       FILTER ( strStarts(str(?order),\"2.\")  ).
    }
    """
}


rule['update_generation_rules'] = {
    'label': "NO-LABEL",
    'order': 0.1030,
    'query': """
    CONSTRUCT {
       cts:generation sh:rule ?rule.
    }
    WHERE {
       ?rule rdf:type sh:SPARQLRule.
       ?rule sh:order ?order.
       FILTER ( strStarts(str(?order),\"3.\")  ).
    }
    """
}


rule['update_generation_class_rules'] = {
    'label': "NO-LABEL",
    'order': 0.1031,
    'query': """
    CONSTRUCT {
       cts:class_generation sh:rule ?rule.
    }
    WHERE {
       { ?rule rdf:type sh:SPARQLRule.
       ?rule sh:order ?order.
       FILTER ( strStarts(str(?order),\"3.1\")  ). }
       UNION
       { ?rule rdf:type sh:SPARQLRule.
       ?rule sh:order ?order.
       FILTER ( strStarts(str(?order),\"3.2\")  ). }
    }
    """
}


rule['update_generation_relation_rules'] = {
    'label': "NO-LABEL",
    'order': 0.1032,
    'query': """
    CONSTRUCT {
       cts:relation_generation sh:rule ?rule.
    }
    WHERE {
       ?rule rdf:type sh:SPARQLRule.
       ?rule sh:order ?order.
       FILTER ( strStarts(str(?order),\"3.3\")  ).
    }
    """
}


rule['update_batch_execution_rules'] = {
    'label': "NO-LABEL",
    'order': 0.104,
    'query': """
    CONSTRUCT {
       cts:batch_execution sh:rule ?rule.
    }
    WHERE {
       ?nodeShapes sh:rule ?rule.
    }
    VALUES ?nodeShapes {
       cts:preprocessing
       cts:net_extension
       cts:generation
    }
    """
}


# ---------------------------------------------
# TODO
# ---------------------------------------------

rule['querry_name'] = {
    'label': "TODO",
    'order': 0.00,
    'query': """
    TODO
    """
}


cts:old_add-event
  rdf:type sh:SPARQLRule ;
  rdfs:label "add-event" ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Add Verb class / instance in System Ontology
CONSTRUCT { 
   # Classification
   ?newEventUri rdfs:subClassOf ?eventClassUri.
   ?newEventUri rdfs:label ?eventLabel.
   ?newEventUri sys:from_structure ?req.
   # Object Property
   ?newEventObjectPropertyUri a owl:ObjectProperty.
   ?newEventObjectPropertyUri rdfs:subPropertyOf ?eventObjectPropertyUri.
   ?newEventObjectPropertyUri rdfs:label ?verbConcept.
   ?newEventObjectPropertyUri sys:from_structure ?req.
   ?actorInstanceUri ?newEventObjectPropertyUri ?targetInstanceUri.
}
WHERE {
   # net1: entity
   ?net1 a net:Instance.
   ?net1 net:type net:atom.
   ?net1 net:atomOf sys:Event.
   ?net1 net:has_structure ?req.
   ?net1 net:has_verb ?verbObject1.
   ?verbObject1 net:has_parent_class ?verbClass.	
   ?verbObject1 net:has_concept ?verbConcept.
   ?net1 net:has_actor ?actorObject1.
   ?actorObject1 net:has_parent_class ?actorClass.	
   ?actorObject1 net:has_concept ?actorConcept.
   ?actorObject1 net:has_instance ?actorInstance.
   ?actorObject1 net:has_instance_uri ?actorInstanceUri.  
   ?net1 net:has_target ?targetObject1.
   ?targetObject1 net:has_parent_class ?targetClass.	
   ?targetObject1 net:has_concept ?targetConcept.
   ?targetObject1 net:has_instance ?targetInstance. 
   ?targetObject1 net:has_instance_uri ?targetInstanceUri. 
   # Label: event
   BIND (concat(?actorConcept, '-', ?verbConcept) AS ?e1).
   BIND (concat(?e1, '-', ?targetConcept) AS ?eventLabel).
   # URI (for classes)
	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
   sys:Event sys:is_class ?eventClass.
   BIND (concat( ?targetOntologyURI, ?eventClass) AS ?c1).
   BIND (concat(?c1, '_', ?eventLabel) AS ?c2).
   BIND (uri( ?c1) AS ?eventClassUri).
   BIND (uri(?c2) AS ?newEventUri).
   # URI (for object property)
   sys:Event sys:has_object_property ?eventObjectProperty.
   BIND (concat( ?targetOntologyURI, ?eventObjectProperty) AS ?o1).
   BIND (concat(?o1, '#', ?verbConcept) AS ?o2).
   BIND (uri( ?o1) AS ?eventObjectPropertyUri).
   BIND (uri( ?o2) AS ?newEventObjectPropertyUri).
}""" ;
  sh:order 0.331 ;


cts:old_add-state-property
  rdf:type sh:SPARQLRule ;
  rdfs:label "add-event" ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Add Verb class / instance in System Ontology
CONSTRUCT { 
   # Classification
   ?newStatePropertyUri rdfs:subClassOf ?statePropertyClassUri.
   ?newStatePropertyUri rdfs:label ?statePropertyLabel.
   ?newStatePropertyUri sys:from_structure ?req.
   # Object Property
   ?newStatePropertyObjectPropertyUri a owl:ObjectProperty.
   ?newStatePropertyObjectPropertyUri rdfs:subPropertyOf ?statePropertyObjectPropertyUri.
   ?newStatePropertyObjectPropertyUri rdfs:label ?verbConcept.
   ?newStatePropertyObjectPropertyUri sys:from_structure ?req.
   ?actorInstanceUri ?newStatePropertyObjectPropertyUri ?targetInstanceUri.
}
WHERE {
   # net1: state property
   ?net1 a net:Instance.
   ?net1 net:type net:atom.
   ?net1 net:atomOf sys:State_Property.
   ?net1 net:has_structure ?req.
   ?net1 net:has_verb ?verbObject1.
   ?verbObject1 net:has_parent_class ?verbClass.	
   ?verbObject1 net:has_concept ?verbConcept.
   ?net1 net:has_actor ?actorObject1.
   ?actorObject1 net:has_parent_class ?actorClass.	
   ?actorObject1 net:has_concept ?actorConcept.
   ?actorObject1 net:has_instance ?actorInstance.
   ?actorObject1 net:has_instance_uri ?actorInstanceUri.  
   ?net1 net:has_target ?targetObject1.
   ?targetObject1 net:has_parent_class ?targetClass.	
   ?targetObject1 net:has_concept ?targetConcept.
   ?targetObject1 net:has_instance ?targetInstance. 
   ?targetObject1 net:has_instance_uri ?targetInstanceUri. 
   # Label: event
   BIND (concat(?actorConcept, '-', ?verbConcept) AS ?e1).
   BIND (concat(?e1, '-', ?targetConcept) AS ?statePropertyLabel).
   # URI (for classes)
	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
   sys:State_Property sys:is_class ?statePropertyClass.
   BIND (concat( ?targetOntologyURI, ?statePropertyClass) AS ?c1).
   BIND (concat(?c1, '_', ?statePropertyLabel) AS ?c2).
   BIND (uri( ?c1) AS ?statePropertyClassUri).
   BIND (uri(?c2) AS ?newStatePropertyUri).
   # URI (for object property)
   sys:State_Property sys:has_object_property ?statePropertyObjectProperty.
   BIND (concat( ?targetOntologyURI, ?statePropertyObjectProperty) AS ?o1).
   BIND (concat(?o1, '#', ?verbConcept) AS ?o2).
   BIND (uri( ?o1) AS ?statePropertyObjectPropertyUri).
   BIND (uri( ?o2) AS ?newStatePropertyObjectPropertyUri).
}""" ;
  sh:order 0.331 ;


cts:old_compose-agt-verb-obj-as-simple-event
  rdf:type sh:SPARQLRule ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Compose a subject (agt), an action Verb and an object (obj) to obtain an event    
CONSTRUCT {
   # Net: Event
   ?newNet a net:Instance.
   ?newNet net:type net:atom.
   ?newNet net:atomOf sys:Event.
   ?newNet net:has_structure ?req.
   ?newNet net:has_node ?uw1, ?uw2, ?uw3.
   ?newNet net:has_actor ?actorObject.	
   ?newNet net:has_verb ?verbObject.	
   ?newNet net:has_target ?targetObject.	
   ?newNet net:has_possible_domain ?domainClass.	
   ?newNet net:has_possible_range ?rangeClass.	
}
WHERE {
   # net1: verb
   ?net1 a net:Instance.
   ?net1 net:type net:atom.
   ?net1 net:atomOf sys:action_verb.
   ?net1 net:has_structure ?req.
   ?net1 net:has_node ?uw1.
   ?net1 net:has_atom ?verbObject.
   # net2: entity (actor)
   ?net2 a net:Instance.
   ?net2 net:type net:atom.
   # -- old --- ?net2 net:atomOf sys:Entity.
   ?net2 net:has_structure ?req.
   ?net2 net:has_node ?uw2.
   ?net2 net:has_atom ?actorObject.
   # net3: entity (target)
   ?net3 a net:Instance.
   ?net3 net:type net:atom.
   # -- old --- ?net3 net:atomOf sys:Entity.
   ?net3 net:has_structure ?req.
   ?net3 net:has_node ?uw3.
   ?net3 net:has_atom ?targetObject.
   # condition: agt(net1, net2) et obj(net1, net3)
   ?uw1 unl:agt ?uw2.
   ?uw1 (unl:obj|unl:res) ?uw3.	
   # Label: Id
   ?uw1 unl:has_id ?uw1Id.
   ?uw2 unl:has_id ?uw2Id.
   ?uw3 unl:has_id ?uw3Id.
   # Possible domain/range
   ?actorObject net:has_instance ?actorObjectInstance.
   ?allActorObject net:has_instance ?actorObjectInstance.
   ?allActorObject net:has_concept ?domainClass.	
   ?targetObject net:has_instance ?targetObjectInstance.
   ?allTargetObject net:has_instance ?targetObjectInstance.
   ?allTargetObject net:has_concept ?rangeClass.	   
   # URI (for Event Net)
   cprm:Config_Parameters cprm:netURI ?netURI.
   net:event rdfs:label ?eventLabel.
   BIND (concat( ?netURI, ?eventLabel, '_') AS ?n1).
   BIND (concat(?n1, ?uw1Id, '-', ?uw2Id, '-', ?uw3Id) AS ?n2).
   BIND (uri(?n2) AS ?newNet).
}""" ;
  sh:order 0.241 ;


cts:old_compose-aoj-verb-obj-as-simple-state-property
  rdf:type sh:SPARQLRule ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Compose a subject (aoj), an attributibe Verb and an object (obj) / result (res) to obtain a state property
CONSTRUCT {
   # Net: State Property
   ?newNet a net:Instance.
   ?newNet net:type net:atom.
   ?newNet net:atomOf sys:State_Property.
   ?newNet net:has_structure ?req.
   ?newNet net:has_node ?uw1, ?uw2, ?uw3.
   ?newNet net:has_actor ?actorObject.	
   ?newNet net:has_verb ?verbObject.	
   ?newNet net:has_target ?targetObject.	
   ?newNet net:has_possible_domain ?domainClass.	
   ?newNet net:has_possible_range ?rangeClass.	
}
WHERE {
   # net1: verb
   ?net1 a net:Instance.
   ?net1 net:type net:atom.
   ?net1 net:atomOf sys:attributive_verb.
   ?net1 net:has_structure ?req.
   ?net1 net:has_node ?uw1.
   ?net1 net:has_atom ?verbObject.
   # net2: entity (actor)
   ?net2 a net:Instance.
   ?net2 net:type net:atom.
   # -- old --- ?net2 net:atomOf sys:Entity.
   ?net2 net:has_structure ?req.
   ?net2 net:has_node ?uw2.
   ?net2 net:has_atom ?actorObject.
   # net3: entity (target)
   ?net3 a net:Instance.
   ?net3 net:type net:atom.
   # -- old --- ?net3 net:atomOf sys:Entity.
   ?net3 net:has_structure ?req.
   ?net3 net:has_node ?uw3.
   ?net3 net:has_atom ?targetObject.
   # condition: aoj(net1, net2) et obj(net1, net3)
   ?uw1 unl:aoj ?uw2.
   ?uw1 (unl:obj|unl:res) ?uw3.	
   # Label: Id
   ?uw1 unl:has_id ?uw1Id.
   ?uw2 unl:has_id ?uw2Id.
   ?uw3 unl:has_id ?uw3Id.
   # Possible domain/range
   ?actorObject net:has_instance ?actorObjectInstance.
   ?allActorObject net:has_instance ?actorObjectInstance.
   ?allActorObject net:has_concept ?domainClass.	
   ?targetObject net:has_instance ?targetObjectInstance.
   ?allTargetObject net:has_instance ?targetObjectInstance.
   ?allTargetObject net:has_concept ?rangeClass.	   
   # URI (for State Property Net)
   cprm:Config_Parameters cprm:netURI ?netURI.
   net:state_property rdfs:label ?statePropertyLabel.
   BIND (concat( ?netURI, ?statePropertyLabel, '_') AS ?n1).
   BIND (concat(?n1, ?uw1Id, '-', ?uw2Id, '-', ?uw3Id) AS ?n2).
   BIND (uri(?n2) AS ?newNet).
}""" ;
  sh:order 0.241 ;


cts:old_compute-domain-range-of-event-object-properties
  rdf:type sh:SPARQLRule ;
  rdfs:label "compute-domain-range-of-object-properties" ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Compute domain/range of object properties
CONSTRUCT { 
   # Object Property: domain, range and relation between domain/range classes
   ?newEventObjectPropertyUri rdfs:domain ?domainClass.
   ?newEventObjectPropertyUri rdfs:range ?rangeClass.
   ?domainClass ?newEventObjectPropertyUri ?rangeClass. # relation between domain/range classes
}
WHERE {
   # net1: event
   ?net1 a net:Instance.
   ?net1 net:type net:atom.
   ?net1 net:atomOf sys:Event.
   ?net1 net:has_structure ?req.
   ?net1 net:has_verb ?verbObject1.	
   ?verbObject1 net:has_concept ?verbConcept.
   # domain  
   ?net1 net:has_possible_domain ?possibleDomainLabel1.
	?domainClass rdfs:label ?possibleDomainLabel1 .
   FILTER (
		NOT EXISTS {
			?net1 net:has_possible_domain ?possibleDomainLabel2 .
	        ?anotherDomainClass rdfs:label ?possibleDomainLabel2 .
			?anotherDomainClass rdfs:subClassOf ?domainClass.
		}
	)
   # range  
   ?net1 net:has_possible_range ?possibleRangeLabel1.
   ?rangeClass rdfs:label ?possibleRangeLabel1 .
   FILTER (
		NOT EXISTS {
			?net1 net:has_possible_domain ?possibleRangeLabel2 .
	        ?anotherRangeClass rdfs:label ?possibleRangeLabel2 .
			?anotherRangeClass rdfs:subClassOf ?rangeClass.
		}
   )
   # URI (for object property)
	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
   sys:Event sys:has_object_property ?eventObjectProperty.
   BIND (concat( ?targetOntologyURI, ?eventObjectProperty) AS ?o1).
   BIND (concat(?o1, '#', ?verbConcept) AS ?o2).
   BIND (uri( ?o2) AS ?newEventObjectPropertyUri).
}""" ;
  sh:order 0.332 ;


cts:old_compute-domain-range-of-state-property-object-properties
  rdf:type sh:SPARQLRule ;
  rdfs:label "compute-domain-range-of-object-properties" ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Compute domain/range of object properties
CONSTRUCT { 
   # Object Property: domain, range and relation between domain/range classes
   ?objectPropertyUri rdfs:domain ?domainClass.
   ?objectPropertyUri rdfs:range ?rangeClass.
   ?domainClass ?objectPropertyUri ?rangeClass. # relation between domain/range classes
}
WHERE {
   # net1: event
   ?net1 a net:Instance.
   ?net1 net:type net:atom.
   ?net1 net:atomOf sys:State_Property.
   ?net1 net:has_structure ?req.
   ?net1 net:has_verb ?verbObject1.	
   ?verbObject1 net:has_concept ?verbConcept.
   # domain  
   ?net1 net:has_possible_domain ?possibleDomainLabel1.
	?domainClass rdfs:label ?possibleDomainLabel1 .
   FILTER (
		NOT EXISTS {
			?net1 net:has_possible_domain ?possibleDomainLabel2 .
	        ?anotherDomainClass rdfs:label ?possibleDomainLabel2 .
			?anotherDomainClass rdfs:subClassOf ?domainClass.
		}
	)
   # range  
   ?net1 net:has_possible_range ?possibleRangeLabel1.
   ?rangeClass rdfs:label ?possibleRangeLabel1 .
   FILTER (
		NOT EXISTS {
			?net1 net:has_possible_domain ?possibleRangeLabel2 .
	       ?anotherRangeClass rdfs:label ?possibleRangeLabel2 .
			?anotherRangeClass rdfs:subClassOf ?rangeClass.
		}
   )
   # URI (for object property)
	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
   sys:State_Property sys:has_object_property ?objectPropertyRef.
   BIND (concat( ?targetOntologyURI, ?objectPropertyRef) AS ?o1).
   BIND (concat(?o1, '#', ?verbConcept) AS ?o2).
   BIND (uri( ?o2) AS ?objectPropertyUri).
}""" ;
  sh:order 0.332 ;


old_link-classes-by-relation-property
  rdf:type sh:SPARQLRule ;
  rdfs:label "link-classes-by-relation-property" ;
  sh:construct """PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>

# -- Link two classes by relation property (according existence of domain and range)
CONSTRUCT { 
   # relation between domain/range classes
   ?domainClassUri ?propertyUri ?rangeClassUri.
}
WHERE {
   # Relation Net (net1)
   ?propertyUri rdfs:domain ?domainClass.
   ?propertyUri rdfs:range ?rangeClass.
   BIND (uri( ?domainClass) AS ?domainClassUri).
   BIND (uri( ?rangeClass) AS ?rangeClassUri).
}""" ;
  sh:order 0.33 ;