#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: UNL CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rules (CTR) for the analysis of 
# UNL structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# Prefix using in CTR
#==============================================================================

prefix = """
PREFIX owl: <http://www.w3.org/2002/07/owl#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>
PREFIX unl: <https://unl.tetras-libre.fr/rdf/schema#>
PREFIX net: <https://tenet.tetras-libre.fr/semantic-net#>
PREFIX cprm: <https://tenet.tetras-libre.fr/config/parameters#>
PREFIX req: <https://tenet.tetras-libre.fr/frame/requirement-ontology#>
PREFIX sys: <https://tenet.tetras-libre.fr/system-ontology/>
PREFIX fprm: <https://tenet.tetras-libre.fr/frame/parameters#>
    
"""


#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule = {}

 
# ---------------------------------------------
# Net Expansion: Atom Net
# ---------------------------------------------

rule['create-atom-net'] = {
    'label': "TODO",
    'comment': "Create Atom Net (entity)",
    'order': 2.11,
    'query': """
    CONSTRUCT { 
        # Object
        ?newObject a net:Object.
        ?newObject net:objectType net:atom.
        ?newObject net:has_node ?uw1.
        ?newObject net:has_mother_class ?atomMother.
        ?newObject net:has_parent_class ?atomClass.
        ?newObject net:has_class ?concept1.
        ?newObject net:has_concept ?concept1.
        # Net
        ?newNet a net:Instance.
        ?newNet net:type net:atom.
        ?newNet net:atomOf ?atomMother.
        ?newNet net:has_structure ?req.
        ?newNet net:has_node ?uw1.
        ?newNet net:has_atom ?newObject.
    }
    WHERE {
        # Atom Description (from System Ontology)
        ?atomMother rdfs:subClassOf* sys:Structure.
        ?atomMother sys:is_class ?atomClass.
        ?atomMother seedSchema:has_uw-regex-seed ?restriction.
        # UW: type UW-Occurrence and substructure of req sentence
        ?uw1 rdf:type unl:UW_Occurrence.
        ?uw1 unl:is_substructure_of ?req.
        # Filter on label
        ?uw1 rdfs:label ?uw1Label.
        FILTER ( regex(str(?uw1Label),str(?restriction))  ).
        # Label: Id, concept
        ?uw1 unl:has_id ?uw1Id.
        BIND (IF (CONTAINS(?uw1Label, '('), strbefore(?uw1Label, '('), str(?uw1Label)) AS ?concept1).
        # URI (for Atom Object)
        cprm:Config_Parameters cprm:netURI ?netURI.
        cprm:Config_Parameters cprm:objectRef ?objectRef.
        net:atom rdfs:label ?atomLabel.
        BIND (concat( ?netURI, ?objectRef, ?atomLabel, '_') AS ?o1).
        BIND (concat(?o1, ?uw1Id) AS ?o2).
        BIND (uri(?o2) AS ?newObject).
        # URI (for Atom Net)
        cprm:Config_Parameters cprm:netURI ?netURI.
        sys:Structure sys:has_reference ?classReference.
        BIND (concat( ?netURI, ?classReference, '-', ?atomClass, '_') AS ?n1).
        BIND (concat(?n1, ?uw1Id) AS ?n2).
        BIND (uri(?n2) AS ?newNet).
    }
    """
}


rule['instantiate-atom-net'] = {
    'label': "NO-LABEL",
    'comment': "Instantiate atom net",
    'order': 2.12,
    'query': """
    CONSTRUCT { 
       # Object: entity 
       ?atomObject1 net:has_instance ?instanceName. 
    }
    WHERE {
       # net1: atom
       ?net1 a net:Instance.
       ?net1 net:type net:atom.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       ?net1 net:has_atom ?atomObject1. 
       # condition: agt/obj(uw0, uw1)
       ?uw0 (unl:agt | unl:obj | unl:aoj) ?uw1.
       # UW: type UW-Occurrence and substructure of req sentence
       ?uw0 rdf:type unl:UW_Occurrence.
       ?uw0 unl:is_substructure_of ?req.
       # Label: id, name
       ?uw1 unl:has_id ?uw1Id.
       BIND (?uw1Id AS ?instanceName).
    }
    """
}


# ---------------------------------------------
# Net Expansion: List
# ---------------------------------------------

rule['create-unary-atom-list-net'] = {
    'label': "NO-LABEL",
    'comment': "Create an unary Atom List net",
    'order': 2.21,
    'query': """
    CONSTRUCT { 
       # Net: Atom List
       ?newNet a net:Instance.
       ?newNet net:type net:list.
       ?newNet net:type net:unary_list.
       ?newNet net:listOf net:atom.
       ?newNet net:has_structure ?req.
       ?newNet net:has_node ?uw1.
       ?newNet net:has_item ?object1.
    }
    WHERE {   
       # Net: Atom
       ?net1 a net:Instance.
       ?net1 net:type net:atom.
       ?net1 net:atomOf ?net1Mother.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       ?net1 net:has_atom ?object1.
       ?object1 net:has_parent_class ?net1ParentClass.
       # selection: target UW of modifier (mod)
       ?uw0 unl:mod ?uw1.
       FILTER NOT EXISTS  { ?uw1 (unl:and|unl:or) ?uw2 }
       # UW: type UW-Occurrence and substructure of req sentence
       ?uw0 rdf:type unl:UW_Occurrence.
       ?uw0 unl:is_substructure_of ?req.
       # Label(s) / URI
       ?uw1 rdfs:label ?uw1Label.
       ?uw1 unl:has_id ?uw1Id.
       cprm:Config_Parameters cprm:netURI ?netURI.
       sys:Structure sys:has_reference ?classReference.
       net:list rdfs:label ?listLabel.
       net:atom rdfs:label ?atomLabel.
       BIND (concat( ?netURI, ?classReference, '-', ?listLabel, '-', ?atomLabel, '_') AS ?s1).
       BIND (concat(?s1, ?uw1Id) AS ?s2).
       BIND (uri(?s2) AS ?newNet).
    }
    """
}


rule['init-conjunctive-atom-list-net'] = {
    'label': "NO-LABEL",
    'comment': "Initialize a conjunctive Atom List net",
    'order': 2.21,
    'query': """
    CONSTRUCT { 
       # Net: Atom List
       ?newNet a net:Instance.
       ?newNet net:type net:list.
       ?newNet net:type net:conjunctive_list.
       ?newNet net:listOf net:atom.
       ?newNet net:has_structure ?req.
       ?newNet net:has_node ?uw1.
       ?newNet net:has_item ?object1.
    }
    WHERE {
       # Net: Atom
       ?net1 a net:Instance.
       ?net1 net:type net:atom.
       ?net1 net:atomOf ?net1Mother.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       ?net1 net:has_atom ?object1.
       ?object1 net:has_parent_class ?net1ParentClass.
       # selection: target UW of modifier (mod)
       ?uw1 unl:and ?uw2.
       # UW: type UW-Occurrence and substructure of req sentence
       ?uw2 rdf:type unl:UW_Occurrence.
       ?uw2 unl:is_substructure_of ?req.
       # Label(s) / URI
       ?uw1 rdfs:label ?uw1Label.
       ?uw1 unl:has_id ?uw1Id.
       cprm:Config_Parameters cprm:netURI ?netURI.
       net:list rdfs:label ?listLabel.
       net:atom rdfs:label ?atomLabel.
       BIND (concat( ?netURI, ?listLabel, '_', ?atomLabel, '_') AS ?s1).
       BIND (concat(?s1, ?uw1Id) AS ?s2).
       BIND (uri(?s2) AS ?newNet).
    }
    """
}


rule['init-disjunctive-atom-list-net'] = {
    'label': "NO-LABEL",
    'comment': "Initialize a disjunctive Atom List net",
    'order': 2.21,
    'query': """
    CONSTRUCT { 
       # Net: Atom List
       ?newNet a net:Instance.
       ?newNet net:type net:list.
       ?newNet net:type net:disjunctive_list.
       ?newNet net:listOf net:atom.
       ?newNet net:has_structure ?req.
       ?newNet net:has_node ?uw1.
       ?newNet net:has_item ?object1.
    }
    WHERE {
       # Net: Atom
       ?net1 a net:Instance.
       ?net1 net:type net:atom.
       ?net1 net:atomOf ?net1Mother.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       ?net1 net:has_atom ?object1.
       ?object1 net:has_parent_class ?net1ParentClass.
       # selection: target UW of modifier (mod)
       ?uw1 unl:or ?uw2.
       # UW: type UW-Occurrence and substructure of req sentence
       ?uw2 rdf:type unl:UW_Occurrence.
       ?uw2 unl:is_substructure_of ?req.
       # Label(s) / URI
       ?uw1 rdfs:label ?uw1Label.
       ?uw1 unl:has_id ?uw1Id.
       cprm:Config_Parameters cprm:netURI ?netURI.
       net:list rdfs:label ?listLabel.
       net:atom rdfs:label ?atomLabel.
       BIND (concat( ?netURI, ?listLabel, '_', ?atomLabel, '_') AS ?s1).
       BIND (concat(?s1, ?uw1Id) AS ?s2).
       BIND (uri(?s2) AS ?newNet).
    }
    """
}


rule['extend-atom-list-net'] = {
    'label': "NO-LABEL",
    'comment': "Extend an Atom List net",
    'order': 2.22,
    'query': """
    CONSTRUCT { 
       # Update Atom List net (net1)
       ?net1 net:has_node ?uw2.
       ?net1 net:has_item ?object2.
    }
    WHERE {
       # Net1: Atom List
       ?net1 a net:Instance.
       ?net1 net:type net:list.
       ?net1 net:listOf net:atom.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       # extension: disjunction of UW
       ?uw1 (unl:or|unl:and) ?uw2.
       # Net2: Atom
       ?net2 a net:Instance.
       ?net2 net:type net:atom.
       ?net2 net:has_structure ?req.
       ?net2 net:has_node ?uw2.
       ?net2 net:has_atom ?object2.
    }
    """
}


rule['specify-axis-of-atom-list-net'] = {
    'label': "NO-LABEL",
    'comment': "Specify axis of Atom List net",
    'order': 2.23,
    'query': """
    CONSTRUCT { 
       # Update Atom List net (net1)
       ?net1 net:listBy ?unlRel.
    }
    WHERE {
       # UW: type UW-Occurrence and substructure of req sentence
       ?uw0 rdf:type unl:UW_Occurrence.
       ?uw0 unl:is_substructure_of ?req.
       # Net: Atom List
       ?net1 a net:Instance.
       ?net1 net:type net:list.
       ?net1 net:listOf net:atom.
       ?net1 net:has_node ?uw1.
       # selection: target UW of modifier (mod)
       ?uw0 ?unlRel ?uw1.
       FILTER NOT EXISTS { ?net1 net:has_node ?uw0 }.
    }
    """
}


# ---------------------------------------------
# Net Expansion: Composition
# ---------------------------------------------

rule['compose-atom-with-list-by-mod-1'] = {
    'label': "NO-LABEL",
    'comment': "Compose an atom net and a list net (with distinct item classes)",
    'order': 2.32,
    'query': """
    CONSTRUCT { 
       # Object: Composite
       ?newObject a net:Object.
       ?newObject net:objectType net:composite.
       ?newObject net:has_node ?uw1, ?uw3.
       ?newObject net:has_mother_class ?net1Mother.
       ?newObject net:has_parent_class ?net1Class.
       ?newObject net:has_class ?subConcept.
       ?newObject net:has_concept ?subConcept.
       ?newObject net:has_feature ?net2Item.
       # Net: Composite List
       ?newNet a net:Instance.
       ?newNet net:type net:list.
       ?newNet net:type ?listSubType.
       ?newNet net:listOf net:composite.
       ?newNet net:has_structure ?req.
       ?newNet net:has_node ?uw1, ?uw2, ?uw3.
       ?newNet net:entityClass ?net1ParentClass.
       ?newNet net:has_parent ?net1Object.	
       ?newNet net:has_item ?newObject.	
    }
    WHERE {
       # net1: atom
       ?net1 a net:Instance.
       ?net1 net:type net:atom.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       ?net1 net:has_atom ?net1Object.
       ?net1Object net:has_mother_class ?net1Mother.
       ?net1Object net:has_parent_class ?net1ParentClass.	
       ?net1Object net:has_class ?net1Class.
       ?net1Object net:has_concept ?net1Concept.
       # condition: mod(net1, net2)
       ?uw1 unl:mod ?uw2.
       # net2: list
       ?net2 a net:Instance.
       ?net2 net:type net:list.
       ?net2 net:type ?listSubType.
       ?net2 net:listOf net:atom.
       ?net2 net:has_structure ?req. 
       ?net2 net:has_node ?uw2, ?uw3.
       ?net2 net:has_item ?net2Item.
       ?net2Item net:has_node ?uw3.
       ?net2Item net:has_parent_class ?net2ParentClass.	
       ?net2Item net:has_concept ?net2Concept.
       # Filter
       FILTER NOT EXISTS { ?net2 net:has_node ?uw1 }.
       FILTER ( ?net1ParentClass != ?net2ParentClass  ).
       # Label: Id, concept
       ?uw1 unl:has_id ?uw1Id.
       ?uw2 unl:has_id ?uw2Id.
       ?uw3 unl:has_id ?uw3Id.
       BIND (concat( ?net2Concept, '_', ?net1Concept) AS ?subConcept).
       # URI (for Object)
       cprm:Config_Parameters cprm:netURI ?netURI.
       cprm:Config_Parameters cprm:objectRef ?objectRef.
       net:composite rdfs:label ?compositeLabel.
       BIND (concat( ?netURI, ?objectRef, ?compositeLabel, '_') AS ?o1).
       BIND (concat(?o1, ?uw1Id, '-', ?uw3Id) AS ?o2).
       BIND (uri(?o2) AS ?newObject).
       # URI (for List Net)
       cprm:Config_Parameters cprm:netURI ?netURI.
       net:list rdfs:label ?listLabel.
       net:composite rdfs:label ?compositeLabel.
       BIND (concat( ?netURI, ?listLabel, '_', ?compositeLabel, '_') AS ?n1).
       BIND (concat(?n1, ?uw1Id, '-', ?uw2Id) AS ?n2).
       BIND (uri(?n2) AS ?newNet).
    }
    """
}
  

rule['compose-atom-with-list-by-mod-2'] = {
    'label': "NO-LABEL",
    'comment': "Compose an atom net and an list net (with same item classes)",
    'order': 2.33,
    'query': """
    CONSTRUCT { 
       # Net: Composite List
       ?newNet a net:Instance.
       ?newNet net:type net:list.
       ?newNet net:type ?listSubType.
       ?newNet net:listOf net:composite.
       ?newNet net:has_structure ?req.
       ?newNet net:has_node ?uw1, ?uw2, ?uw3.
       ?newNet net:entityClass ?net1ParentClass.
       ?newNet net:has_parent ?net1Object.	
       ?newNet net:has_item ?net2Item.	
    }
    WHERE {
       # net1: atom
       ?net1 a net:Instance.
       ?net1 net:type net:atom.
       ?net1 net:has_structure ?req.
       ?net1 net:has_node ?uw1.
       ?net1 net:has_atom ?net1Object.
       ?net1Object net:has_parent_class ?net1ParentClass.	
       # condition: mod(net1, net2)
       ?uw1 unl:mod ?uw2.
       # net2: list
       ?net2 a net:Instance.
       ?net2 net:type net:list.
       ?net2 net:listOf net:atom.
       ?net2 net:has_structure ?req.
       ?net2 net:has_node ?uw2, ?uw3.
       ?net2 net:has_item ?net2Item.
       ?net2Item net:has_node ?uw3.
       ?net2Item net:has_parent_class ?net2ParentClass.	
       ?net2Item net:has_concept ?net2Concept.
       # Filter
       FILTER NOT EXISTS { ?net2 net:has_node ?uw1 }.
       FILTER ( ?net1ParentClass = ?net2ParentClass  ).
       # Label: Id, subEntity
       ?uw1 unl:has_id ?uw1Id.
       ?uw2 unl:has_id ?uw2Id.
       ?uw3 unl:has_id ?uw3Id.
       # URI (for List Net)
       cprm:Config_Parameters cprm:netURI ?netURI.
       net:list rdfs:label ?listLabel.
       net:composite rdfs:label ?compositeLabel.
       BIND (concat( ?netURI, ?listLabel, '_', ?compositeLabel, '_') AS ?n1).
       BIND (concat(?n1, ?uw1Id, '-', ?uw2Id) AS ?n2).
       BIND (uri(?n2) AS ?newNet).
    }
    """
}


rule['instantiate-composite-in-list-by-extension-1'] = {
    'label': "NO-LABEL",
    'comment': "Instantiate composite in list by extension of instances from parent element",
    'order': 2.341,
    'query': """
    CONSTRUCT { 
       ?itemObject net:has_instance ?parentInstance. 
    }
    WHERE {
       # net1: Composite List
       ?net1 a net:Instance.
       ?net1 net:type net:list.
       ?net1 net:listOf net:composite.
       ?net1 net:has_parent ?parentObject.
       ?parentObject net:has_instance ?parentInstance. 
       ?net1 net:has_item ?itemObject.	
       # Filter
       FILTER NOT EXISTS { ?itemObject net:has_instance ?anyInstance } .
    }
    """
}


rule['instantiate-composite-in-list-by-extension-2'] = {
    'label': "NO-LABEL",
    'comment': "Instantiate entities in class list by extension of instances (2)",
    'order': 2.342,
    'query': """
    CONSTRUCT { 
       ?net2SubObject net:has_instance ?parentInstance. 
    }
    WHERE {
       # net1: Composite List
       ?net1 a net:Instance.
       ?net1 net:type net:list.
       ?net1 net:listOf net:composite.
       ?net1 net:has_structure ?sameReq.
       ?net1 net:has_parent ?parentObject.
       ?parentObject net:has_instance ?parentInstance. 
       ?net1 net:has_item ?net1SubObject.	
       ?net1SubObject net:has_concept ?sameEntity.	
       # net2: Another List
       ?net2 a net:Instance.
       ?net2 net:type net:list.
       ?net2 net:listOf net:composite.
       ?net2 net:has_structure ?sameReq.
       ?net2 net:has_parent ?net2MainObject.
       ?net2MainObject net:has_concept ?sameEntity.	
       ?net2 net:has_item ?net2SubObject.	
       # Filter
       FILTER NOT EXISTS { ?net2SubObject net:has_instance ?anyInstance } .
    }
    """
}
  
  
# ---------------------------------------------
# Net Expansion: Relation Net
# ---------------------------------------------

rule['create-relation-net'] = {
    'label': "NO-LABEL",
    'comment': "Create relation net",
    'order': 2.41,
    'query': """
    CONSTRUCT {
       # Object
       ?newObject a net:Object.
       ?newObject net:objectType net:relation.
       ?newObject net:has_node ?uw1.
       ?newObject net:has_parent_property ?relationMother.
       ?newObject net:has_concept ?verbConcept.
       # create: Relation Net
       ?newNet a net:Instance.
       ?newNet net:type net:relation.
       ?newNet net:relationOf ?relationMother.
       ?newNet net:has_structure ?req.
       ?newNet net:has_node ?uw1.
       ?newNet net:has_relation ?newObject.	
    }
    WHERE {
       	# Relation Description (from System Ontology)
       	?targetProperty rdfs:subPropertyOf* sys:Relation.
       	?targetProperty sys:has_mother_property ?relationMother.
       	?targetProperty sys:has_reference ?relationReference.
      	# -- old --- ?targetProperty sys:has_restriction_on_class ?classRestriction.
    	?targetProperty seedSchema:has_class-restriction-seed ?classRestriction.
       	# Atom Net (net1): restricted net according to its atom category (atomOf) 
       	?net1 a net:Instance.
       	?net1 net:type net:atom.
       	?net1 net:atomOf ?classRestriction.
       	?net1 net:has_structure ?req.
       	?net1 net:has_node ?uw1.
       	# -- Verb Actor
       	?net1 net:has_atom ?verbObject.
       	?verbObject net:has_mother_class ?verbMother.
       	?verbObject net:has_parent_class ?verbParentClass.
       	?verbObject net:has_concept ?verbConcept.
       	# Label: Id
       	?uw1 unl:has_id ?uw1Id. 
       	# URI (for Atom Object)
       	cprm:Config_Parameters cprm:netURI ?netURI.
       	cprm:Config_Parameters cprm:objectRef ?objectRef.
       	net:relation rdfs:label ?relationLabel.
       	BIND (concat( ?netURI, ?objectRef, ?relationLabel, '_') AS ?o1).
       	BIND (concat(?o1, ?uw1Id) AS ?o2).
       	BIND (uri(?o2) AS ?newObject).
       	# URI (for Event Net)
       	cprm:Config_Parameters cprm:netURI ?netURI.
       	sys:Property sys:has_reference ?propertyReference.
       	BIND (concat( ?netURI, ?propertyReference, '-', ?relationReference, '_') AS ?n1).
       	BIND (concat(?n1, ?uw1Id) AS ?n2).
       	BIND (uri(?n2) AS ?newNet).
    }
    """
}
 
  
rule['append-domain-to-relation-net'] = {
    'label': "NO-LABEL",
    'comment': "Append possible domain, actor to relation nets",
    'order': 2.42,
    'query': """
    CONSTRUCT {
       # update: Relation Net (net1)
       ?net1 net:has_node ?uw1, ?uw2.
       ?net1 net:has_source ?sourceObject.	
       ?net1 net:has_possible_domain ?domainClass.	
    }
    WHERE {
       # Relation Net (net1)
       ?net1 a net:Instance.
       ?net1 net:type net:relation.
       ?net1 net:has_structure ?req.
       # -- Relation Object
       ?net1 net:has_relation ?relationObject.	
       ?relationObject net:has_node ?uw1.
       # Atom Net (net2): actor of net1
       ?net2 a net:Instance.
       ?net2 net:type net:atom.
       ?net2 net:has_structure ?req.
       ?net2 net:has_node ?uw2.
       ?net2 net:has_atom ?sourceObject.
       # condition: agt(net1, net2)
       ?uw1 ( unl:agt | unl:aoj ) ?uw2.
       # Possible Domain
       { ?sourceObject net:has_concept ?domainClass. }
       UNION
       { ?sourceObject net:has_instance ?sourceInstance.
       ?anySourceObject net:has_instance ?sourceInstance.
       ?anySourceObject net:has_concept ?domainClass. }	
    }
    """
}


rule['append-range-to-relation-net'] = {
    'label': "NO-LABEL",
    'comment': "Append possible range, target to relation nets ",
    'order': 2.42,
    'query': """
    CONSTRUCT {
       # update: Relation Net (net1)
       ?net1 net:has_node ?uw1, ?uw2.
       ?net1 net:has_target ?targetObject.	
       ?net1 net:has_possible_range ?rangeClass.
    }
    WHERE {
       # Relation Net (net1)
       ?net1 a net:Instance.
       ?net1 net:type net:relation.
       ?net1 net:has_structure ?req.
       # -- Relation Object
       ?net1 net:has_relation ?relationObject.	
       ?relationObject net:has_node ?uw1.
       # Atom Net (net2): target of net1
       ?net2 a net:Instance.
       ?net2 net:type net:atom.
       ?net2 net:has_structure ?req.
       ?net2 net:has_node ?uw2.
       ?net2 net:has_atom ?targetObject.
       # condition: agt(net1, net2)
       ?uw1 (unl:obj|unl:res) ?uw2.
       # Possible Domain
       { ?targetObject net:has_concept ?rangeClass. }
       UNION
       { ?targetObject net:has_instance ?targetObjectInstance.
       ?allTargetObject net:has_instance ?targetObjectInstance.
       ?allTargetObject net:has_concept ?rangeClass. }	  
    }
    """
}
  
  
# ---------------------------------------------
# Net Expansion: URI Computation
# ---------------------------------------------

rule['compute-class-uri-of-net-object'] = {
    'label': "compute-class-uri-of-net-object",
    'comment': "Compute useful URI",
    'order': 2.91,
    'query': """
    CONSTRUCT { 
       # Net Object URI
       ?object net:has_mother_class_uri ?motherClassUri.
       ?object net:has_parent_class_uri ?parentClassUri.
       ?object net:has_class_uri ?objectClassUri.
    }
    WHERE {
       # object
       ?object a net:Object.
       ?object net:objectType ?objectType.
       ?object net:has_mother_class ?motherClass.	
       ?object net:has_parent_class ?parentClass.	
       ?object net:has_class ?objectClass.
       # URI (for classes)
    	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
    	cprm:Config_Parameters cprm:newClassRef ?newClassRef.
       BIND (str(?motherClass) AS ?s1).
       # TODO: BIND (concat( ?targetOntologyURI, ?motherClass) AS ?s1). 
       BIND (concat(?targetOntologyURI, ?parentClass) AS ?s2).
       BIND (concat(?targetOntologyURI, ?newClassRef, ?objectClass) AS ?s3).
       BIND (uri( ?s1) AS ?motherClassUri).
       BIND (uri( ?s2) AS ?parentClassUri).
       BIND (uri(?s3) AS ?objectClassUri).
    }
    VALUES ?objectType { 
       net:atom
       net:composite 
    }
    """
}


rule['compute-instance-uri-of-net-object'] = {
    'label': "compute-instance-uri-of-net-object",
    'comment': "Compute useful URI",
    'order': 2.92,
    'query': """
    CONSTRUCT { 
       # Net Object URI
       ?object net:has_instance_uri ?objectInstanceUri.
    }
    WHERE {
       # object
       ?object a net:Object.
       ?object net:has_parent_class ?parentClass.	
       ?object net:has_instance ?objectInstance. 
       # URI (for classes and instance)
    	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
       BIND (concat( ?targetOntologyURI, ?parentClass) AS ?s1).
       BIND (concat(?s1, '#', ?objectInstance) AS ?s2).
       BIND (uri(?s2) AS ?objectInstanceUri).
    }
    """
}


rule['compute-property-uri-of-relation-object'] = {
    'label': "compute-property-uri-of-relation-object",
    'comment': "Compute useful URI",
    'order': 2.91,
    'query': """
    CONSTRUCT { 
       # Net Object URI
       ?object net:has_property_uri ?objectPropertyUri.
    }
    WHERE {
       # Object of type Relation
       ?object a net:Object.
       ?object net:objectType ?objectType.	
       ?object net:has_parent_property ?parentProperty.
       ?object net:has_concept ?objectConcept.
       # URI (for object property)
    	cprm:Config_Parameters cprm:targetOntologyURI ?targetOntologyURI.
    	cprm:Config_Parameters cprm:newPropertyRef ?newPropertyRef.
       ?parentProperty sys:has_reference ?relationReference.
       BIND (concat( ?targetOntologyURI, ?newPropertyRef, ?relationReference) AS ?o1).
       BIND (concat(?o1, '_', ?objectConcept) AS ?o2).
       BIND (uri( ?o2) AS ?objectPropertyUri).
    }
    VALUES ?objectType { 
       net:relation
    }
    """
}