#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Semantic Net Class Test
#------------------------------------------------------------------------------
# Script to test the semantic net classes
#==============================================================================

import subprocess, os

import rdflib
from rdflib import Graph, Namespace, URIRef
from rdflib.namespace import NamespaceManager

FILE_PATH = f'{os.path.dirname(os.path.abspath(__file__))}'
INPUT_DIR_PATH = f'{FILE_PATH}/input/'
OUTPUT_DIR_PATH = f'{FILE_PATH}/output/'
TEST_GRAPH = f'{INPUT_DIR_PATH}testGraph1.ttl'

from context import tenet

from tenet.febTransduction.net import Net

from tenet.febTransduction.net import ClassNet
from tenet.febTransduction.net import AtomClassNet
from tenet.febTransduction.net import CompositeClassNet

from tenet.febTransduction.net import PropertyNet
from tenet.febTransduction.net import AtomPropertyNet
from tenet.febTransduction.net import CompositePropertyNet

from tenet.febTransduction.net import IndividualNet

from tenet.febTransduction.net import ValueNet

from tenet.febTransduction.net import PhenomenaNet

from tenet.febTransduction.net import RestrictionNet



#==============================================================================
# Useful Methods
#==============================================================================

def load_test_graph():
    print(f'\n -- Test Graph Loading')
    graph = Graph()
    graph.bind('amr', Namespace('https://amr.tetras-libre.fr/rdf/schema#'))
    graph.bind('net', Namespace('https://tenet.tetras-libre.fr/semantic-net#'))
    graph.bind('base-out', Namespace('https://tenet.tetras-libre.fr/base-ontology#'))
    graph.parse(TEST_GRAPH)
    print(f" ----- Graph Loaded ({len(graph)})")
    return graph


def test_attribute_access(net, *attr_set):
    print(f'\n *** Net attributes ({net.type_id})) ***')
    for attr in attr_set:
        print(f' ----- {attr}: {eval(attr)}')        
       


#==============================================================================
# Development Test
#==============================================================================

def devtest_set_uri_attribute(graph):
    print('\n -- Set URI attribute')
    uri = 'https://tenet.tetras-libre.fr/semantic-net#atomClass_sun_s2'
    print(f' ----- uri (1): {uri}')
    if isinstance(uri, rdflib.term.URIRef):
        uri = uri.n3(graph.namespace_manager)
    elif isinstance(uri, str):
        uri = URIRef(uri).n3(graph.namespace_manager)
    print(f' ----- uri (1): {uri}')
    

#==============================================================================
# Unit Test
#==============================================================================

def unittest_get_attribute_net(graph, net_uri):
    print('\n -- Net')
    net_uri = 'https://tenet.tetras-libre.fr/semantic-net#atomClass_sun_s2'
    net = Net(graph, uri=net_uri)
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming')

def unittest_get_attribute_class_net(graph, net_uri):
    print('\n -- Class Net')
    net = ClassNet(graph, uri='net:atomClass_sun_s2')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.class_name')

def unittest_get_attribute_atom_class_net(graph, net_uri):    
    print('\n -- Atom Class Net')
    net = AtomClassNet(graph, uri='net:atomClass_sun_s2')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.class_name') 

def unittest_get_attribute_composite_class_net(graph, net_uri):    
    print('\n -- Composite Class Net')
    net = CompositeClassNet(graph, uri='net:compositeClass_orbit-hasManner-conjunction-OR_o2')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.class_name',
                          'net.mother_class_net', 'net.restriction', 'net.restriction01')

def unittest_get_attribute_property_net(graph, net_uri):    
    print('\n -- Property Net')
    net = PropertyNet(graph, uri='net:atomProperty_orbit_o2')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.property_name')
 
def unittest_get_attribute_atom_property_net(graph, net_uri):   
    print('\n -- Atom Property Net')
    net = AtomPropertyNet(graph, uri='net:atomProperty_orbit_o2')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.property_name',
                          'net.core_role', 'net.target_argument_node', 'net.property_type',
                          'net.property_name01', 'net.property_name10', 'net.property_name12')

def unittest_get_attribute_composite_property_net(graph, net_uri):    
    print('\n -- Composite Property Net')
    net = CompositePropertyNet(graph, uri='net:compositeProperty_not-direct_d2')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.property_name',
                          'net.core_role', 'net.target_argument_node', 'net.property_type', 'net.restriction')

def unittest_get_attribute_individual_net(graph, net_uri):    
    print('\n -- Individual Net')
    net = IndividualNet(graph, uri='net:individual_system_SolarSystem')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.base_class_name', 'net.mother_class_net', 'net.individual_label')

def unittest_get_attribute_value_net(graph, net_uri):    
    print('\n -- Value Net')
    net = ValueNet(graph, uri='net:value_SolarSystem_blankNode')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.value_label')
 
def unittest_get_attribute_phenomena_net(graph, net_uri):   
    print('\n -- Phenomena Net')
    net = PhenomenaNet(graph, uri='net:phenomena_conjunction-AND_a')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.phenomena_type', 'net.phenomena_ref')

def unittest_get_attribute_restriction_net(graph, net_uri):    
    print('\n -- Restriction Net')
    net = RestrictionNet(graph, uri='net:restriction_hasPart_sun')
    test_attribute_access(net, 'net.uri', 
                          'net.node', 'net.base_node', 'net.structure', 'net.naming',
                          'net.target_node', 'net.restriction_property', 'net.restriction_net_value')


#==============================================================================
# Test Script
#==============================================================================

if __name__ == '__main__':
      
    print('\n *** Test Preparation ***')
    graph = load_test_graph()
    print('\n \n')
    
    print('\n *** Development Test ***')
    devtest_set_uri_attribute(graph)
    print('\n \n')
    
    print('\n *** Unit Test ***')
    unittest_get_attribute_net(graph, 'https://tenet.tetras-libre.fr/semantic-net#atomClass_sun_s2')

    unittest_get_attribute_class_net(graph, 'net:atomClass_sun_s2')
    unittest_get_attribute_atom_class_net(graph, 'net:atomClass_sun_s2')
    unittest_get_attribute_composite_class_net(graph, 'net:compositeClass_orbit-hasManner-conjunction-OR_o2')
    unittest_get_attribute_composite_class_net(graph, 'net:compositeClass_system-hasPart-sun-and-object_s')

    unittest_get_attribute_property_net(graph, 'net:atomProperty_orbit_o2')     
    unittest_get_attribute_atom_property_net(graph, 'net:atomProperty_orbit_o2')
    unittest_get_attribute_composite_property_net(graph, 'net:compositeProperty_not-direct_d2')
    
    unittest_get_attribute_individual_net(graph, 'net:individual_system_SolarSystem')  

    unittest_get_attribute_value_net(graph, 'net:value_SolarSystem_blankNode')  
     
    unittest_get_attribute_phenomena_net(graph, 'net:phenomena_conjunction-AND_a')
    unittest_get_attribute_phenomena_net(graph, 'net:phenomena_conjunction-OR_o3') 

    unittest_get_attribute_restriction_net(graph, 'net:restriction_hasPart_sun')  
                      
    print('\n \n')