#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Semantic Net Class Test
#------------------------------------------------------------------------------
# Script to test the semantic net classes
#==============================================================================

import subprocess, os
from rdflib import Graph
from rdflib import Namespace
from rdflib.namespace import NamespaceManager

FILE_PATH = f'{os.path.dirname(os.path.abspath(__file__))}'
INPUT_DIR_PATH = f'{FILE_PATH}/input/'
OUTPUT_DIR_PATH = f'{FILE_PATH}/output/'
TEST_GRAPH = f'{INPUT_DIR_PATH}testGraph1.ttl'

from context import tenet

from tenet.febTransduction.net import Net

from tenet.febTransduction.net import ClassNet
from tenet.febTransduction.net import AtomClassNet
from tenet.febTransduction.net import CompositeClassNet

from tenet.febTransduction.net import PropertyNet
from tenet.febTransduction.net import AtomPropertyNet
from tenet.febTransduction.net import CompositePropertyNet

from tenet.febTransduction.net import IndividualNet

from tenet.febTransduction.net import ValueNet

from tenet.febTransduction.net import PhenomenaNet

from tenet.febTransduction.net import RestrictionNet



#==============================================================================
# Utilities
#==============================================================================

def test_attribute_access(net, *attr_set):
    print(f'\n *** Net attributes ({net.type_id})) ***')
    for attr in attr_set:
        print(f' ----- {attr}: {eval(attr)}')        
       





#==============================================================================
# Development Test
#==============================================================================

print('\n' + ' *** Development Test ***')
print('\n *** TEST: Semantic Net Composition ***')

print(f'\n -- Test Graph Loading')
graph = Graph()
graph.bind('net', Namespace('https://tenet.tetras-libre.fr/semantic-net#'))
graph.parse(TEST_GRAPH)
print(f" ----- Graph Loaded ({len(graph)})")

print('\n -- Nets to compose')
net_1 = AtomClassNet(graph, uri='net:atomClass_object_o')
print(f' ----- net_1: {net_1.uri} ({net_1.naming})') 
net_2 = PropertyNet(graph, uri='net:atomProperty_orbit_o2')
print(f' ----- net_2: {net_2.uri} ({net_2.naming})') 
net_3 = AtomClassNet(graph, uri='net:atomClass_sun_s2')
print(f' ----- net_3: {net_3.uri} ({net_3.naming})') 

print('\n -- New Net constructed by composition')
new_net = CompositeClassNet(graph)
print('\n /// before composition')
test_attribute_access(new_net, 'net.uri', 
                      'net.node', 'net.base_node', 'net.structure', 'net.naming')

new_net.compose(net_1, net_2, net_3)

print('\n /// after composition')
test_attribute_access(new_net, 'net.uri', 
                      'net.node', 'net.base_node', 'net.structure', 'net.naming')
    
print('\n' + ' *** - ***')